@@ -1,18 +1,12 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2019 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2019 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Package implementing the conda GUI logic.
 """
 
-from __future__ import unicode_literals
-try:
-    str = unicode       # __IGNORE_EXCEPTION__
-except NameError:
-    pass
-
 import json
 import os
 
@@ -72,12 +66,12 @@ class Conda(QObject):
         
         dlg = CondaExecDialog("create", self.__ui)
         dlg.start(args)
-        dlg.exec_()
+        dlg.exec()
         ok, resultDict = dlg.getResult()
         
         if ok:
-            if "actions" in resultDict and \
-                    "PREFIX" in resultDict["actions"]:
+            if ("actions" in resultDict and
+                    "PREFIX" in resultDict["actions"]):
                 prefix = resultDict["actions"]["PREFIX"]
             elif "prefix" in resultDict:
                 prefix = resultDict["prefix"]
@@ -395,7 +389,7 @@ class Conda(QObject):
             
             dlg = CondaExecDialog("update", self.__ui)
             dlg.start(args)
-            dlg.exec_()
+            dlg.exec()
             ok, _ = dlg.getResult()
         else:
             ok = False
@@ -435,7 +429,7 @@ class Conda(QObject):
         
         dlg = CondaExecDialog("update", self.__ui)
         dlg.start(args)
-        dlg.exec_()
+        dlg.exec()
         ok, _ = dlg.getResult()
         
         return ok
@@ -476,7 +470,7 @@ class Conda(QObject):
             
             dlg = CondaExecDialog("install", self.__ui)
             dlg.start(args)
-            dlg.exec_()
+            dlg.exec()
             ok, _ = dlg.getResult()
         else:
             ok = False
@@ -507,8 +501,8 @@ class Conda(QObject):
             raise RuntimeError("One of 'name' or 'prefix' must be given.")
         
         if packages:
-            from UI.DeleteFilesConfirmationDialog import \
-                DeleteFilesConfirmationDialog
+            from UI.DeleteFilesConfirmationDialog import (
+                DeleteFilesConfirmationDialog)
             dlg = DeleteFilesConfirmationDialog(
                 self.parent(),
                 self.tr("Uninstall Packages"),
@@ -516,7 +510,7 @@ class Conda(QObject):
                     "Do you really want to uninstall these packages and"
                     " their dependencies?"),
                 packages)
-            if dlg.exec_() == QDialog.Accepted:
+            if dlg.exec() == QDialog.Accepted:
                 args = [
                     "remove",
                     "--json",
@@ -532,7 +526,7 @@ class Conda(QObject):
                 
                 dlg = CondaExecDialog("remove", self.__ui)
                 dlg.start(args)
-                dlg.exec_()
+                dlg.exec()
                 ok, _ = dlg.getResult()
             else:
                 ok = False
@@ -602,7 +596,7 @@ class Conda(QObject):
                 try:
                     packages = json.loads(output)
                     ok = "error" not in packages
-                except Exception:
+                except Exception:       # secok
                     # return values for errors is already set
                     pass
         
@@ -628,7 +622,7 @@ class Conda(QObject):
         
         dlg = CondaExecDialog("update", self.__ui)
         dlg.start(args)
-        dlg.exec_()
+        dlg.exec()
         ok, _ = dlg.getResult()
         
         return ok
@@ -737,4 +731,4 @@ class Conda(QObject):
         
         dlg = CondaExecDialog("clean", self.__ui)
         dlg.start(args)
-        dlg.exec_()
+        dlg.exec()
