@@ -7,7 +7,6 @@
 Module implementing the chat dialog.
 """
 
-
 from PyQt5.QtCore import Qt, pyqtSlot, pyqtSignal, QDateTime, QPoint, QFileInfo
 from PyQt5.QtGui import QColor
 from PyQt5.QtWidgets import QWidget, QListWidgetItem, QMenu, QApplication
@@ -574,10 +573,9 @@ class ChatWidget(QWidget, Ui_ChatWidget):
                     fname = Utilities.toNativeSeparators(fname)
                 
                 try:
-                    f = open(fname, "w", encoding="utf-8")
-                    f.write(txt)
-                    f.close()
-                except IOError as err:
+                    with open(fname, "w", encoding="utf-8") as f:
+                        f.write(txt)
+                except OSError as err:
                     E5MessageBox.critical(
                         self,
                         self.tr("Error saving Chat"),
