@@ -242,7 +242,7 @@ class PyProfileDialog(QDialog, Ui_PyProfileDialog):
         try:
             with open(fname, 'rb') as f:
                 self.stats = pickle.load(f)     # secok
-        except (EnvironmentError, pickle.PickleError, EOFError):
+        except (OSError, pickle.PickleError, EOFError):
             E5MessageBox.critical(
                 self,
                 self.tr("Loading Profiling Data"),
