@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2002 - 2019 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2002 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -15,17 +15,12 @@ import inspect
 import ctypes
 import time
 from inspect import CO_GENERATOR
+import dis
 
 from BreakpointWatch import Breakpoint, Watch
 
-if sys.version_info[0] == 2:
-    import thread as _thread
-    from inspect import getargvalues, formatargvalues
-else:
-    import _thread
-    from DebugUtilities import getargvalues, formatargvalues
-    unicode = str
-    basestring = str
+import _thread
+from DebugUtilities import getargvalues, formatargvalues
 
 gRecursionLimit = 64
 
@@ -169,7 +164,7 @@ class DebugBase(object):
                 import __pypy__
                 __pypy__.locals_to_fast(cf)
                 return
-        except Exception:
+        except Exception:       # secok
             pass
         
         ctypes.pythonapi.PyFrame_LocalsToFast(
@@ -383,10 +378,7 @@ class DebugBase(object):
         if frame is None:
             frame = sys._getframe().f_back  # Skip set_trace method
         
-        if sys.version_info[0] == 2:
-            stopOnHandleCommand = self._dbgClient.handleJsonCommand.func_code
-        else:
-            stopOnHandleCommand = self._dbgClient.handleJsonCommand.__code__
+        stopOnHandleCommand = self._dbgClient.handleJsonCommand.__code__
         
         frame.f_trace = self.trace_dispatch
         while frame.f_back is not None:
@@ -459,7 +451,7 @@ class DebugBase(object):
             sys.settrace(self.trace_dispatch)
         
         try:
-            exec(cmd, globalsDict, localsDict)
+            exec(cmd, globalsDict, localsDict)      # secok
             atexit._run_exitfuncs()
             self._dbgClient.progTerminated(0)
         except SystemExit:
@@ -621,14 +613,13 @@ class DebugBase(object):
             lineNo = frame.f_code.co_firstlineno
             lineNumbers = [lineNo]
             
-            if sys.version_info[0] == 2:
-                co_lnotab = map(ord, frame.f_code.co_lnotab[1::2])
-            else:
-                co_lnotab = frame.f_code.co_lnotab[1::2]
+            co_lnotab = frame.f_code.co_lnotab[1::2]
             
             # No need to handle special case if a lot of lines between
             # (e.g. closure), because the additional lines won't cause a bp
             for co_lno in co_lnotab:
+                if co_lno >= 0x80:
+                    lineNo -= 0x100
                 lineNo += co_lno
                 lineNumbers.append(lineNo)
             
@@ -807,7 +798,6 @@ class DebugBase(object):
         
         if exctype in [SyntaxError, IndentationError]:
             try:
-                # tuple could only occure on Python 2, but not always!
                 if type(excval) == tuple:
                     message, details = excval
                     filename, lineno, charno, text = details
@@ -868,13 +858,7 @@ class DebugBase(object):
         else:
             exctypetxt = str(exctype)
         
-        if sys.version_info[0] == 2:
-            try:
-                excvaltxt = unicode(excval).encode(self._dbgClient.getCoding())
-            except UnicodeError:
-                excvaltxt = str(excval)
-        else:
-            excvaltxt = str(excval)
+        excvaltxt = str(excval)
         
         # Don't step into libraries, which are used by our debugger methods
         if exctb is not None:
@@ -882,10 +866,12 @@ class DebugBase(object):
         
         self.isBroken = True
         
+        disassembly = None
         stack = []
         if exctb:
             frlist = self.__extract_stack(exctb)
             frlist.reverse()
+            disassembly = self.__disassemble(frlist[0][0])
             
             self.currentFrame = frlist[0][0]
             stack = self.getStack(frlist[self.skipFrames:])
@@ -894,6 +880,7 @@ class DebugBase(object):
         self._dbgClient.currentThread = self
         self._dbgClient.currentThreadExec = self
         self._dbgClient.sendException(exctypetxt, excvaltxt, stack)
+        self._dbgClient.setDisassembly(disassembly)
         self._dbgClient.dumpThreadList()
         
         if exctb is not None:
@@ -918,14 +905,7 @@ class DebugBase(object):
         @param exctype type of the exception
         @return exception name (string)
         """
-        if sys.version_info[0] == 2:
-            if type(exctype) in [types.ClassType,   # Python up to 2.4
-                                 types.TypeType]:   # Python 2.5+
-                return exctype.__name__
-            else:
-                return exctype
-        else:
-            return str(exctype).replace("<class '", "").replace("'>", "")
+        return str(exctype).replace("<class '", "").replace("'>", "")
     
     def __extract_stack(self, exctb):
         """
@@ -942,6 +922,60 @@ class DebugBase(object):
         tb = None
         return stack
 
+    def __disassemble(self, frame):
+        """
+        Private method to generate a disassembly of the given code object.
+        
+        @param frame frame object to be disassembled
+        @type code
+        @return dictionary containing the disassembly information
+        @rtype dict
+        """
+        co = frame.f_code
+        disDict = {
+            "lasti": frame.f_lasti,
+            "firstlineno": co.co_firstlineno,
+            "instructions": [],
+        }
+        
+        # 1. disassembly info
+        for instr in dis.get_instructions(co):
+            instrDict = {
+                "lineno":
+                    0 if instr.starts_line is None else instr.starts_line,
+                "isJumpTarget": instr.is_jump_target,
+                "offset": instr.offset,
+                "opname": instr.opname,
+                "arg": instr.arg,
+                "argrepr": instr.argrepr,
+            }
+            disDict["instructions"].append(instrDict)
+        
+        # 2. code info
+        # Note: keep in sync with PythonDisViewer.__createCodeInfo()
+        disDict["codeinfo"] = {
+            "name": co.co_name,
+            "filename": co.co_filename,
+            "firstlineno": co.co_firstlineno,
+            "argcount": co.co_argcount,
+            "kwonlyargcount": co.co_kwonlyargcount,
+            "nlocals": co.co_nlocals,
+            "stacksize": co.co_stacksize,
+            "flags": dis.pretty_flags(co.co_flags),
+            "consts": [str(const) for const in co.co_consts],
+            "names": [str(name) for name in co.co_names],
+            "varnames": [str(name) for name in co.co_varnames],
+            "freevars": [str(var) for var in co.co_freevars],
+            "cellvars": [str(var) for var in co.co_cellvars],
+        }
+        try:
+            disDict["codeinfo"]["posonlyargcount"] = co.co_posonlyargcount
+        except AttributeError:
+            # does not exist prior to 3.8.0
+            disDict["codeinfo"]["posonlyargcount"] = 0
+        
+        return disDict
+    
     def __extractSystemExitMessage(self, excinfo):
         """
         Private method to get the SystemExit code and message.
@@ -955,7 +989,7 @@ class DebugBase(object):
         if excval is None:
             exitcode = 0
             message = ""
-        elif isinstance(excval, basestring):
+        elif isinstance(excval, str):
             exitcode = 1
             message = excval
         elif isinstance(excval, bytes):
@@ -966,7 +1000,7 @@ class DebugBase(object):
             message = ""
         elif isinstance(excval, SystemExit):
             code = excval.code
-            if isinstance(code, basestring):
+            if isinstance(code, str):
                 exitcode = 1
                 message = code
             elif isinstance(code, bytes):
@@ -1044,6 +1078,3 @@ class DebugBase(object):
         except AttributeError:
             # if frame is None
             return True
-    
-#
-# eflag: noqa = M702
