@@ -224,7 +224,7 @@ class DebugClientBase(object):
                     # read the first and second line
                     text = f.readline()
                     text = "{0}{1}".format(text, f.readline())
-            except IOError:
+            except OSError:
                 self.__coding = default
                 return
             
@@ -1169,7 +1169,7 @@ class DebugClientBase(object):
             
             try:
                 rrdy, wrdy, xrdy = select.select([self.readstream], wrdy, [])
-            except (select.error, KeyboardInterrupt, socket.error):
+            except (KeyboardInterrupt, OSError):
                 selectErrors += 1
                 if selectErrors <= 10:      # arbitrarily selected
                     # just carry on
@@ -1212,7 +1212,7 @@ class DebugClientBase(object):
         # immediate return if nothing is ready.
         try:
             rrdy, wrdy, xrdy = select.select([self.readstream], wrdy, [], 0)
-        except (select.error, KeyboardInterrupt, socket.error):
+        except (KeyboardInterrupt, OSError):
             return
 
         if self.readstream in rrdy:
