@@ -1,23 +1,22 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2005 - 2019 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2005 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the Breakpoint viewer widget.
 """
 
-from __future__ import unicode_literals
-
-from PyQt5.QtCore import pyqtSignal, Qt, QItemSelectionModel, \
-    QSortFilterProxyModel, QFileInfo
-from PyQt5.QtWidgets import QTreeView, QAbstractItemView, QHeaderView, QMenu, \
-    QDialog
+from PyQt5.QtCore import (
+    pyqtSignal, Qt, QItemSelectionModel, QSortFilterProxyModel, QFileInfo
+)
+from PyQt5.QtWidgets import (
+    QTreeView, QAbstractItemView, QHeaderView, QMenu, QDialog
+)
 
 from E5Gui.E5Application import e5App
 
-from Globals import qVersionTuple, recentNameBreakpointFiles, \
-    recentNameBreakpointConditions
+from Globals import recentNameBreakpointFiles, recentNameBreakpointConditions
 
 import Preferences
 
@@ -80,10 +79,7 @@ class BreakPointViewer(QTreeView):
         header = self.header()
         header.setSortIndicator(0, Qt.AscendingOrder)
         header.setSortIndicatorShown(True)
-        if qVersionTuple() >= (5, 0, 0):
-            header.setSectionsClickable(True)
-        else:
-            header.setClickable(True)
+        header.setSectionsClickable(True)
         
         self.setSortingEnabled(True)
         
@@ -172,15 +168,15 @@ class BreakPointViewer(QTreeView):
         self.backMenuActions = {}
         self.backMenu = QMenu()
         self.backMenu.addAction(self.tr("Add"), self.__addBreak)
-        self.backMenuActions["EnableAll"] = \
-            self.backMenu.addAction(self.tr("Enable all"),
-                                    self.__enableAllBreaks)
-        self.backMenuActions["DisableAll"] = \
-            self.backMenu.addAction(self.tr("Disable all"),
-                                    self.__disableAllBreaks)
-        self.backMenuActions["DeleteAll"] = \
-            self.backMenu.addAction(self.tr("Delete all"),
-                                    self.__deleteAllBreaks)
+        self.backMenuActions["EnableAll"] = self.backMenu.addAction(
+            self.tr("Enable all"),
+            self.__enableAllBreaks)
+        self.backMenuActions["DisableAll"] = self.backMenu.addAction(
+            self.tr("Disable all"),
+            self.__disableAllBreaks)
+        self.backMenuActions["DeleteAll"] = self.backMenu.addAction(
+            self.tr("Delete all"),
+            self.__deleteAllBreaks)
         self.backMenu.aboutToShow.connect(self.__showBackMenu)
         self.backMenu.addSeparator()
         self.backMenu.addAction(self.tr("Configure..."), self.__configure)
@@ -241,7 +237,7 @@ class BreakPointViewer(QTreeView):
         dlg = EditBreakpointDialog((self.fnHistory[0], None), None,
                                    self.condHistory, self, modal=1,
                                    addMode=1, filenameHistory=self.fnHistory)
-        if dlg.exec_() == QDialog.Accepted:
+        if dlg.exec() == QDialog.Accepted:
             fn, line, cond, temp, enabled, count = dlg.getAddData()
             if fn is not None:
                 if fn in self.fnHistory:
@@ -294,7 +290,7 @@ class BreakPointViewer(QTreeView):
             dlg = EditBreakpointDialog(
                 (fn, line), (cond, temp, enabled, count),
                 self.condHistory, self, modal=True)
-            if dlg.exec_() == QDialog.Accepted:
+            if dlg.exec() == QDialog.Accepted:
                 cond, temp, enabled, count = dlg.getData()
                 if cond:
                     if cond in self.condHistory:
@@ -494,9 +490,8 @@ class BreakPointViewer(QTreeView):
         self.condHistory = []
         rs = Preferences.Prefs.rsettings.value(recentNameBreakpointConditions)
         if rs is not None:
-            self.condHistory = \
-                Preferences.toList(rs)[
-                    :Preferences.getDebugger("RecentNumber")]
+            self.condHistory = Preferences.toList(rs)[
+                :Preferences.getDebugger("RecentNumber")]
     
     def __saveRecent(self):
         """
