@@ -1046,7 +1046,7 @@ class DebugUI(QObject):
                         self.ui, Program,
                         self.tr('<p><b>{0}</b> has terminated with an exit'
                                 ' status of {1}.</p>{2}')
-                            .format(Utilities.normabspath(self.ui.currentProg),
+                            .format(os.path.abspath(self.ui.currentProg),
                                     status, info))
             else:
                 if message:
@@ -1077,7 +1077,7 @@ class DebugUI(QObject):
                         self.appendStdout.emit(self.tr(
                             '"{0}" has terminated with an exit status of'
                             ' {1}.\n{2}\n').format(
-                            Utilities.normabspath(self.ui.currentProg), status,
+                            os.path.abspath(self.ui.currentProg), status,
                             info))
 
     def __clientSyntaxError(self, message, filename, lineNo, characterNo):
@@ -1163,7 +1163,7 @@ class DebugUI(QObject):
                             pass
                         if "__IGNORE_EXCEPTION__" in lineFlags:
                             res = E5MessageBox.No
-                except (UnicodeError, IOError):
+                except (UnicodeError, OSError):
                     pass
                 if res != E5MessageBox.No:
                     self.viewmanager.setFileLine(
