@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2002 - 2019 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2002 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -20,14 +20,13 @@ The views avaliable are:
 </ul>
 """
 
-from __future__ import unicode_literals
-
 import os
 
 from PyQt5.QtCore import pyqtSignal
-from PyQt5.QtWidgets import QWidget, QVBoxLayout, QHBoxLayout, QLineEdit, \
-    QSizePolicy, QPushButton, QComboBox, QLabel, QTreeWidget, \
-    QTreeWidgetItem, QHeaderView
+from PyQt5.QtWidgets import (
+    QWidget, QVBoxLayout, QHBoxLayout, QLineEdit, QSizePolicy, QPushButton,
+    QComboBox, QLabel, QTreeWidget, QTreeWidgetItem, QHeaderView
+)
 
 import UI.PixmapCache
 import Preferences
@@ -62,7 +61,7 @@ class DebugViewer(QWidget):
         self.debugServer = debugServer
         self.debugUI = None
         
-        self.setWindowIcon(UI.PixmapCache.getIcon("eric.png"))
+        self.setWindowIcon(UI.PixmapCache.getIcon("eric"))
         
         self.__mainLayout = QVBoxLayout()
         self.__mainLayout.setContentsMargins(0, 0, 0, 0)
@@ -105,7 +104,7 @@ class DebugViewer(QWidget):
         
         index = self.__tabWidget.addTab(
             self.glvWidget,
-            UI.PixmapCache.getIcon("globalVariables.png"), '')
+            UI.PixmapCache.getIcon("globalVariables"), '')
         self.__tabWidget.setTabToolTip(index, self.globalsViewer.windowTitle())
         
         self.setGlobalsFilterButton.clicked.connect(
@@ -159,7 +158,7 @@ class DebugViewer(QWidget):
         
         index = self.__tabWidget.addTab(
             self.lvWidget,
-            UI.PixmapCache.getIcon("localVariables.png"), '')
+            UI.PixmapCache.getIcon("localVariables"), '')
         self.__tabWidget.setTabToolTip(index, self.localsViewer.windowTitle())
         
         self.sourceButton.clicked.connect(self.__showSource)
@@ -177,7 +176,7 @@ class DebugViewer(QWidget):
         self.callStackViewer = CallStackViewer(self.debugServer)
         index = self.__tabWidget.addTab(
             self.callStackViewer,
-            UI.PixmapCache.getIcon("step.png"), "")
+            UI.PixmapCache.getIcon("callStack"), "")
         self.__tabWidget.setTabToolTip(
             index, self.callStackViewer.windowTitle())
         self.callStackViewer.sourceFile.connect(self.sourceFile)
@@ -189,7 +188,7 @@ class DebugViewer(QWidget):
         self.callTraceViewer = CallTraceViewer(self.debugServer)
         index = self.__tabWidget.addTab(
             self.callTraceViewer,
-            UI.PixmapCache.getIcon("callTrace.png"), "")
+            UI.PixmapCache.getIcon("callTrace"), "")
         self.__tabWidget.setTabToolTip(
             index, self.callTraceViewer.windowTitle())
         self.callTraceViewer.sourceFile.connect(self.sourceFile)
@@ -200,7 +199,7 @@ class DebugViewer(QWidget):
         self.breakpointViewer.setModel(self.debugServer.getBreakPointModel())
         index = self.__tabWidget.addTab(
             self.breakpointViewer,
-            UI.PixmapCache.getIcon("breakpoints.png"), '')
+            UI.PixmapCache.getIcon("breakpoints"), '')
         self.__tabWidget.setTabToolTip(
             index, self.breakpointViewer.windowTitle())
         self.breakpointViewer.sourceFile.connect(self.sourceFile)
@@ -211,7 +210,7 @@ class DebugViewer(QWidget):
         self.watchpointViewer.setModel(self.debugServer.getWatchPointModel())
         index = self.__tabWidget.addTab(
             self.watchpointViewer,
-            UI.PixmapCache.getIcon("watchpoints.png"), '')
+            UI.PixmapCache.getIcon("watchpoints"), '')
         self.__tabWidget.setTabToolTip(
             index, self.watchpointViewer.windowTitle())
         
@@ -220,10 +219,20 @@ class DebugViewer(QWidget):
         self.exceptionLogger = ExceptionLogger()
         index = self.__tabWidget.addTab(
             self.exceptionLogger,
-            UI.PixmapCache.getIcon("exceptions.png"), '')
+            UI.PixmapCache.getIcon("exceptions"), '')
         self.__tabWidget.setTabToolTip(
             index, self.exceptionLogger.windowTitle())
         
+        from UI.PythonDisViewer import PythonDisViewer, PythonDisViewerModes
+        # add the Python disassembly viewer
+        self.disassemblyViewer = PythonDisViewer(
+            None, mode=PythonDisViewerModes.TracebackMode)
+        index = self.__tabWidget.addTab(
+            self.disassemblyViewer,
+            UI.PixmapCache.getIcon("disassembly"), '')
+        self.__tabWidget.setTabToolTip(
+            index, self.disassemblyViewer.windowTitle())
+        
         self.__tabWidget.setCurrentWidget(self.glvWidget)
         
         # add the threads viewer
@@ -281,6 +290,7 @@ class DebugViewer(QWidget):
         self.__threadList.clear()
         self.__tabWidget.setCurrentWidget(self.glvWidget)
         self.breakpointViewer.handleResetUI()
+        self.disassemblyViewer.clear()
         
     def initCallStackViewer(self, projectMode):
         """
@@ -433,6 +443,8 @@ class DebugViewer(QWidget):
         self.setLocalsFilter()
         self.showVariablesTab(False)
         
+        self.disassemblyViewer.clear()
+        
     def currentWidget(self):
         """
         Public method to get a reference to the current widget.
