@@ -12,7 +12,7 @@ import os
 import logging
 
 from PyQt5.QtCore import (
-    QObject, QTextCodec, QProcess, QProcessEnvironment, QTimer
+    QObject, QProcess, QProcessEnvironment, QTimer
 )
 from PyQt5.QtWidgets import QInputDialog
 
@@ -63,9 +63,6 @@ class DebuggerInterfacePython(QObject):
         # set translation function
         self.translate = self.__identityTranslation
         
-        self.codec = QTextCodec.codecForName(
-            str(Preferences.getSystem("StringEncoding")))
-        
         if passive:
             # set translation function
             if Preferences.getDebugger("PathTranslation"):
@@ -1038,10 +1035,8 @@ class DebuggerInterfacePython(QObject):
         """
         while self.qsock and self.qsock.canReadLine():
             qs = self.qsock.readLine()
-            if self.codec is not None:
-                line = self.codec.toUnicode(qs)
-            else:
-                line = bytes(qs).decode()
+            line = bytes(qs).decode(
+                encoding=Preferences.getSystem("StringEncoding"))
             
             logging.debug("<Debug-Server> %s", line)
 ##            print("Server: ", line)          ##debug
