@@ -7,7 +7,6 @@
 Module implementing a TabWidget class substituting QTabWidget.
 """
 
-
 from PyQt5.QtCore import pyqtSignal, Qt, QPoint, QMimeData
 from PyQt5.QtGui import QDrag
 from PyQt5.QtWidgets import QTabWidget, QTabBar, QApplication, QStyle
@@ -95,7 +94,7 @@ class E5DnDTabBar(E5WheelTabBar):
             mimeData.setData("action", b"tab-reordering")
             mimeData.setData("tabbar-id", str(id(self)).encode("utf-8"))
             drag.setMimeData(mimeData)
-            drag.exec_()
+            drag.exec()
         E5WheelTabBar.mouseMoveEvent(self, event)
     
     def dragEnterEvent(self, event):
