@@ -7,7 +7,6 @@
 Module implementing a horizontal search widget for QTextEdit.
 """
 
-
 from PyQt5.QtCore import pyqtSlot, Qt, QMetaObject, QSize
 from PyQt5.QtGui import QPalette, QBrush, QColor, QTextDocument, QTextCursor
 from PyQt5.QtWidgets import (
@@ -185,8 +184,10 @@ class E5TextEditSearchWidget(QWidget):
         @type QTextEdit, QWebEngineView or QWebView
         @param editType type of the attached edit widget
         @type str (one of "QTextEdit", "QWebEngineView" or "QWebView")
+        @exception ValueError raised to indicate a bad parameter value
         """
-        assert editType in ["QTextEdit", "QWebEngineView", "QWebView"]
+        if editType not in ["QTextEdit", "QWebEngineView", "QWebView"]:
+            raise ValueError("Bad value for 'editType' parameter.")
         
         self.__textedit = textedit
         self.__texteditType = editType
