@@ -1,18 +1,18 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2008 - 2019 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2008 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing a toolbar configuration dialog.
 """
 
-from __future__ import unicode_literals
-
 from PyQt5.QtCore import pyqtSlot, Qt
 from PyQt5.QtGui import QColor
-from PyQt5.QtWidgets import QDialog, QDialogButtonBox, QTreeWidgetItem, \
-    QInputDialog, QLineEdit, QListWidgetItem, QAbstractButton
+from PyQt5.QtWidgets import (
+    QDialog, QDialogButtonBox, QTreeWidgetItem, QInputDialog, QLineEdit,
+    QListWidgetItem, QAbstractButton
+)
 
 from E5Gui import E5MessageBox
 
@@ -71,13 +71,13 @@ class E5ToolBarDialog(QDialog, Ui_E5ToolBarDialog):
         self.__toolBarItemToWidgetActionID = {}
         # maps toolbar item IDs to widget action IDs
         
-        self.upButton.setIcon(UI.PixmapCache.getIcon("1uparrow.png"))
-        self.downButton.setIcon(UI.PixmapCache.getIcon("1downarrow.png"))
-        self.leftButton.setIcon(UI.PixmapCache.getIcon("1leftarrow.png"))
-        self.rightButton.setIcon(UI.PixmapCache.getIcon("1rightarrow.png"))
+        self.upButton.setIcon(UI.PixmapCache.getIcon("1uparrow"))
+        self.downButton.setIcon(UI.PixmapCache.getIcon("1downarrow"))
+        self.leftButton.setIcon(UI.PixmapCache.getIcon("1leftarrow"))
+        self.rightButton.setIcon(UI.PixmapCache.getIcon("1rightarrow"))
         
-        self.__restoreDefaultsButton = \
-            self.buttonBox.button(QDialogButtonBox.RestoreDefaults)
+        self.__restoreDefaultsButton = self.buttonBox.button(
+            QDialogButtonBox.RestoreDefaults)
         self.__resetButton = self.buttonBox.button(QDialogButtonBox.Reset)
         
         self.actionsTree.header().hide()
@@ -115,8 +115,8 @@ class E5ToolBarDialog(QDialog, Ui_E5ToolBarDialog):
                     actionIDs.append(aID)
                     if aID in self.__widgetActionToToolBarItemID:
                         self.__widgetActionToToolBarItemID[aID] = id(tbItem)
-                        self.__toolBarItemToWidgetActionID[id(tbItem)]\
-                            .append(aID)
+                        self.__toolBarItemToWidgetActionID[id(tbItem)].append(
+                            aID)
             tbItem.actionIDs = actionIDs
             self.toolbarComboBox.addItem(tb.windowTitle(), int(id(tbItem)))
             if default:
@@ -177,8 +177,10 @@ class E5ToolBarDialog(QDialog, Ui_E5ToolBarDialog):
             index = self.toolbarComboBox.currentIndex()
             tbItemID = self.toolbarComboBox.itemData(index)
             tbItem = self.__toolbarItems[tbItemID]
-            if tbItem.toolBarId is not None and \
-               tbItem.toolBarId not in self.__removedToolBarIDs:
+            if (
+                tbItem.toolBarId is not None and
+                tbItem.toolBarId not in self.__removedToolBarIDs
+            ):
                 self.__removedToolBarIDs.append(tbItem.toolBarId)
             del self.__toolbarItems[tbItemID]
             for widgetActionID in self.__toolBarItemToWidgetActionID[tbItemID]:
@@ -213,8 +215,7 @@ class E5ToolBarDialog(QDialog, Ui_E5ToolBarDialog):
                 return
             index = self.toolbarComboBox.currentIndex()
             self.toolbarComboBox.setItemText(index, newName)
-            tbItem = \
-                self.__toolbarItems[self.toolbarComboBox.itemData(index)]
+            tbItem = self.__toolbarItems[self.toolbarComboBox.itemData(index)]
             tbItem.title = newName
             tbItem.isChanged = True
     
@@ -239,8 +240,10 @@ class E5ToolBarDialog(QDialog, Ui_E5ToolBarDialog):
         self.upButton.setEnabled(row > 0)
         self.downButton.setEnabled(row < self.toolbarActionsList.count() - 1)
         self.leftButton.setEnabled(self.toolbarActionsList.count() > 0)
-        rightEnable = self.actionsTree.currentItem().parent() is not None or \
+        rightEnable = (
+            self.actionsTree.currentItem().parent() is not None or
             self.actionsTree.currentItem().text(0) == self.__separatorText
+        )
         self.rightButton.setEnabled(rightEnable)
     
     @pyqtSlot(int)
@@ -339,8 +342,8 @@ class E5ToolBarDialog(QDialog, Ui_E5ToolBarDialog):
         self.__currentToolBarItem.isChanged = True
         if actionID in self.__widgetActionToToolBarItemID:
             self.__widgetActionToToolBarItemID[actionID] = None
-            self.__toolBarItemToWidgetActionID[id(self.__currentToolBarItem)]\
-                .remove(actionID)
+            self.__toolBarItemToWidgetActionID[
+                id(self.__currentToolBarItem)].remove(actionID)
         itm = self.toolbarActionsList.takeItem(row)
         del itm
         self.toolbarActionsList.setCurrentRow(row)
@@ -358,8 +361,8 @@ class E5ToolBarDialog(QDialog, Ui_E5ToolBarDialog):
             item.setText(self.__separatorText)
             actionID = None
         else:
-            actionID = self.actionsTree.currentItem()\
-                .data(0, E5ToolBarDialog.ActionIdRole)
+            actionID = self.actionsTree.currentItem().data(
+                0, E5ToolBarDialog.ActionIdRole)
             action = self.__manager.actionById(actionID)
             item.setText(action.text())
             item.setIcon(action.icon())
@@ -373,10 +376,10 @@ class E5ToolBarDialog(QDialog, Ui_E5ToolBarDialog):
                 if oldTbItemID is not None:
                     self.__toolbarItems[oldTbItemID].actionIDs.remove(actionID)
                     self.__toolbarItems[oldTbItemID].isChanged = True
-                    self.__toolBarItemToWidgetActionID[oldTbItemID]\
-                        .remove(actionID)
-                self.__widgetActionToToolBarItemID[actionID] = \
-                    id(self.__currentToolBarItem)
+                    self.__toolBarItemToWidgetActionID[oldTbItemID].remove(
+                        actionID)
+                self.__widgetActionToToolBarItemID[actionID] = id(
+                    self.__currentToolBarItem)
                 self.__toolBarItemToWidgetActionID[
                     id(self.__currentToolBarItem)].append(actionID)
         self.toolbarActionsList.insertItem(row, item)
