@@ -39,7 +39,7 @@ class PackageDiagramBuilder(UMLDiagramBuilder):
         super(PackageDiagramBuilder, self).__init__(dialog, view, project)
         self.setObjectName("PackageDiagram")
         
-        self.package = Utilities.normabspath(package)
+        self.package = os.path.abspath(package)
         self.noAttrs = noAttrs
     
     def initialize(self):
