@@ -8,7 +8,6 @@ Module implementing some utility functions and the MicroPythonDevice base
 class.
 """
 
-
 import sys
 
 from PyQt5.QtCore import pyqtSlot, QProcess
@@ -179,7 +178,7 @@ class EspDevice(MicroPythonDevice):
                                   showProgress=True)
             res = dlg.startProcess(sys.executable, flashArgs)
             if res:
-                dlg.exec_()
+                dlg.exec()
     
     @pyqtSlot()
     def __flashMicroPython(self):
@@ -190,7 +189,7 @@ class EspDevice(MicroPythonDevice):
         """
         from .EspFirmwareSelectionDialog import EspFirmwareSelectionDialog
         dlg = EspFirmwareSelectionDialog()
-        if dlg.exec_() == QDialog.Accepted:
+        if dlg.exec() == QDialog.Accepted:
             chip, firmware, flashMode, _ = dlg.getData()
             if chip == "esp8266":
                 flashAddress = "0x0000"
@@ -219,7 +218,7 @@ class EspDevice(MicroPythonDevice):
                                   showProgress=True)
             res = dlg.startProcess(sys.executable, flashArgs)
             if res:
-                dlg.exec_()
+                dlg.exec()
     
     @pyqtSlot()
     def __flashAddons(self):
@@ -228,7 +227,7 @@ class EspDevice(MicroPythonDevice):
         """
         from .EspFirmwareSelectionDialog import EspFirmwareSelectionDialog
         dlg = EspFirmwareSelectionDialog(addon=True)
-        if dlg.exec_() == QDialog.Accepted:
+        if dlg.exec() == QDialog.Accepted:
             chip, firmware, flashMode, flashAddress = dlg.getData()
             flashArgs = [
                 "-u",
@@ -250,7 +249,7 @@ class EspDevice(MicroPythonDevice):
                                   showProgress=True)
             res = dlg.startProcess(sys.executable, flashArgs)
             if res:
-                dlg.exec_()
+                dlg.exec()
     
     @pyqtSlot()
     def __backupFlash(self):
@@ -261,7 +260,7 @@ class EspDevice(MicroPythonDevice):
             EspBackupRestoreFirmwareDialog
         )
         dlg = EspBackupRestoreFirmwareDialog(backupMode=True)
-        if dlg.exec_() == QDialog.Accepted:
+        if dlg.exec() == QDialog.Accepted:
             chip, flashSize, flashMode, firmware = dlg.getData()
             flashArgs = [
                 "-u",
@@ -277,7 +276,7 @@ class EspDevice(MicroPythonDevice):
                                   showProgress=True)
             res = dlg.startProcess(sys.executable, flashArgs)
             if res:
-                dlg.exec_()
+                dlg.exec()
     
     @pyqtSlot()
     def __restoreFlash(self):
@@ -288,7 +287,7 @@ class EspDevice(MicroPythonDevice):
             EspBackupRestoreFirmwareDialog
         )
         dlg = EspBackupRestoreFirmwareDialog(backupMode=False)
-        if dlg.exec_() == QDialog.Accepted:
+        if dlg.exec() == QDialog.Accepted:
             chip, flashSize, flashMode, firmware = dlg.getData()
             flashArgs = [
                 "-u",
@@ -311,7 +310,7 @@ class EspDevice(MicroPythonDevice):
                                   showProgress=True)
             res = dlg.startProcess(sys.executable, flashArgs)
             if res:
-                dlg.exec_()
+                dlg.exec()
     
     @pyqtSlot()
     def __showChipID(self):
@@ -328,7 +327,7 @@ class EspDevice(MicroPythonDevice):
                               self.tr("Show Chip ID"))
         res = dlg.startProcess(sys.executable, args)
         if res:
-            dlg.exec_()
+            dlg.exec()
     
     @pyqtSlot()
     def __showFlashID(self):
@@ -345,7 +344,7 @@ class EspDevice(MicroPythonDevice):
                               self.tr("Show Flash ID"))
         res = dlg.startProcess(sys.executable, args)
         if res:
-            dlg.exec_()
+            dlg.exec()
     
     @pyqtSlot()
     def __showMACAddress(self):
@@ -362,7 +361,7 @@ class EspDevice(MicroPythonDevice):
                               self.tr("Show MAC Address"))
         res = dlg.startProcess(sys.executable, args)
         if res:
-            dlg.exec_()
+            dlg.exec()
     
     @pyqtSlot()
     def __resetDevice(self):
