@@ -661,7 +661,7 @@ class MicroPythonFileManagerWidget(QWidget, Ui_MicroPythonFileManagerWidget):
                 os.mkdir(dirPath)
                 self.__listLocalFiles(cwdWidget.text(),
                                       localDevice=localDevice)
-            except (OSError, IOError) as exc:
+            except OSError as exc:
                 E5MessageBox.critical(
                     self,
                     self.tr("Create Directory"),
@@ -737,7 +737,7 @@ class MicroPythonFileManagerWidget(QWidget, Ui_MicroPythonFileManagerWidget):
                     os.remove(filename)
                     self.__listLocalFiles(cwdWidget.text(),
                                           localDevice=localDevice)
-                except (OSError, IOError) as exc:
+                except OSError as exc:
                     E5MessageBox.critical(
                         self,
                         self.tr("Delete File"),
