@@ -7,14 +7,12 @@
 Module implementing the multi project management functionality.
 """
 
-
 import os
 import shutil
 
 from PyQt5.QtCore import (
-    pyqtSignal, pyqtSlot, Qt, QFileInfo, QFile, QIODevice, QObject, QUuid
+    pyqtSignal, pyqtSlot, QFileInfo, QFile, QIODevice, QObject, QUuid
 )
-from PyQt5.QtGui import QCursor
 from PyQt5.QtWidgets import QMenu, QApplication, QDialog, QToolBar
 
 from Globals import recentNameMultiProject
@@ -22,6 +20,7 @@ from Globals import recentNameMultiProject
 from E5Gui.E5Action import E5Action, createActionGroup
 from E5Gui import E5FileDialog, E5MessageBox, E5PathPickerDialog
 from E5Gui.E5PathPickerDialog import E5PathPickerModes
+from E5Gui.E5OverrideCursor import E5OverrideCursor
 
 import UI.PixmapCache
 
@@ -225,14 +224,14 @@ class MultiProject(QObject):
         """
         f = QFile(fn)
         if f.open(QIODevice.ReadOnly):
-            from E5XML.MultiProjectReader import MultiProjectReader
-            reader = MultiProjectReader(f, self)
-            reader.readXML()
-            f.close()
+            with E5OverrideCursor():
+                from E5XML.MultiProjectReader import MultiProjectReader
+                reader = MultiProjectReader(f, self)
+                reader.readXML()
+                f.close()
             if reader.hasError():
                 return False
         else:
-            QApplication.restoreOverrideCursor()
             E5MessageBox.critical(
                 self.ui,
                 self.tr("Read multiproject file"),
@@ -324,7 +323,7 @@ class MultiProject(QObject):
             startdir = Preferences.getMultiProject("Workspace")
         dlg = AddProjectDialog(self.ui, startdir=startdir,
                                categories=self.categories, category=category)
-        if dlg.exec_() == QDialog.Accepted:
+        if dlg.exec() == QDialog.Accepted:
             name, filename, isMaster, description, category, uid = (
                 dlg.getData()
             )
@@ -503,7 +502,7 @@ class MultiProject(QObject):
             
         from .PropertiesDialog import PropertiesDialog
         dlg = PropertiesDialog(self, True)
-        if dlg.exec_() == QDialog.Accepted:
+        if dlg.exec() == QDialog.Accepted:
             self.closeMultiProject()
             dlg.storeData()
             self.opened = True
@@ -520,7 +519,7 @@ class MultiProject(QObject):
         """
         from .PropertiesDialog import PropertiesDialog
         dlg = PropertiesDialog(self, False)
-        if dlg.exec_() == QDialog.Accepted:
+        if dlg.exec() == QDialog.Accepted:
             dlg.storeData()
             self.setDirty(True)
             self.multiProjectPropertiesChanged.emit()
@@ -553,13 +552,10 @@ class MultiProject(QObject):
         QApplication.processEvents()
         
         if fn is not None:
-            QApplication.setOverrideCursor(QCursor(Qt.WaitCursor))
-            QApplication.processEvents()
             self.closeMultiProject()
-            if self.__readMultiProject(fn):
+            ok = self.__readMultiProject(fn)
+            if ok:
                 self.opened = True
-                QApplication.restoreOverrideCursor()
-                QApplication.processEvents()
                 
                 self.closeAct.setEnabled(True)
                 self.saveasAct.setEnabled(True)
@@ -571,8 +567,6 @@ class MultiProject(QObject):
                 if openMaster and Preferences.getMultiProject(
                         "OpenMasterAutomatically"):
                     self.__openMasterProject(False)
-            else:
-                QApplication.restoreOverrideCursor()
     
     def saveMultiProject(self):
         """
