@@ -1400,7 +1400,7 @@ class IrcChannelWidget(QWidget, Ui_IrcChannelWidget):
                         txt = self.messages.toPlainText()
                     with open(fname, "w", encoding="utf-8") as f:
                         f.write(txt)
-                except IOError as err:
+                except OSError as err:
                     E5MessageBox.critical(
                         self,
                         self.tr("Error saving Messages"),
