@@ -454,7 +454,7 @@ class IrcNetworkWidget(QWidget, Ui_IrcNetworkWidget):
                         txt = self.messages.toPlainText()
                     with open(fname, "w", encoding="utf-8") as f:
                         f.write(txt)
-                except IOError as err:
+                except OSError as err:
                     E5MessageBox.critical(
                         self,
                         self.tr("Error saving Messages"),
