@@ -1,23 +1,18 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2012 - 2019 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2012 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the IRC window.
 """
 
-from __future__ import unicode_literals
-try:
-    str = unicode
-except NameError:
-    pass
-
 import re
 import logging
 
-from PyQt5.QtCore import pyqtSlot, pyqtSignal, Qt, QByteArray, QTimer, \
-    QDateTime
+from PyQt5.QtCore import (
+    pyqtSlot, pyqtSignal, Qt, QByteArray, QTimer, QDateTime
+)
 from PyQt5.QtWidgets import QWidget, QToolButton, QLabel, QTabWidget
 from PyQt5.QtNetwork import QTcpSocket, QAbstractSocket
 try:
@@ -65,7 +60,7 @@ class IrcWidget(QWidget, Ui_IrcWidget):
         
         self.__leaveButton = QToolButton(self)
         self.__leaveButton.setIcon(
-            UI.PixmapCache.getIcon("ircCloseChannel.png"))
+            UI.PixmapCache.getIcon("ircCloseChannel"))
         self.__leaveButton.setToolTip(
             self.tr("Press to leave the current channel"))
         self.__leaveButton.clicked.connect(self.__leaveChannel)
@@ -117,7 +112,7 @@ class IrcWidget(QWidget, Ui_IrcWidget):
         self.__prefixRe = re.compile(r""".*\sPREFIX=\((.*)\)([^ ]+).*""")
         self.__chanTypesRe = re.compile(r""".*\sCHANTYPES=([^ ]+).*""")
         
-        ircPic = UI.PixmapCache.getPixmap("irc128.png")
+        ircPic = UI.PixmapCache.getPixmap("irc128")
         self.__emptyLabel = QLabel()
         self.__emptyLabel.setPixmap(ircPic)
         self.__emptyLabel.setAlignment(Qt.AlignVCenter | Qt.AlignHCenter)
@@ -289,7 +284,7 @@ class IrcWidget(QWidget, Ui_IrcWidget):
         """
         from .IrcNetworkListDialog import IrcNetworkListDialog
         dlg = IrcNetworkListDialog(self.__ircNetworkManager, self)
-        dlg.exec_()
+        dlg.exec()
     
     def __networkDataChanged(self):
         """
@@ -801,8 +796,8 @@ class IrcWidget(QWidget, Ui_IrcWidget):
             parts = message.strip().split()
             message = self.tr(
                 "Server {0} (Version {1}), User-Modes: {2},"
-                " Channel-Modes: {3}")\
-                .format(parts[1], parts[2], parts[3], parts[4])
+                " Channel-Modes: {3}"
+            ).format(parts[1], parts[2], parts[3], parts[4])
         elif code == 265:
             parts = message.strip().split()
             message = self.tr(
