@@ -460,7 +460,7 @@ class Pip(QObject):
                     try:
                         with open(requirements, "r") as f:
                             reqs = f.read().splitlines()
-                    except (OSError, IOError):
+                    except OSError:
                         return
                     
                     from UI.DeleteFilesConfirmationDialog import (
