@@ -831,6 +831,7 @@ class PipPackagesWidget(QWidget, Ui_PipPackagesWidget):
             if packages:
                 self.__pip.installPackages(packages, venvName=venvName,
                                            userSite=userSite)
+                self.on_refreshButton_clicked()
     
     @pyqtSlot()
     def on_showDetailsButton_clicked(self):
@@ -1014,6 +1015,7 @@ class PipPackagesWidget(QWidget, Ui_PipPackagesWidget):
         venvName = self.environmentsComboBox.currentText()
         if venvName:
             self.__pip.installPip(venvName)
+            self.on_refreshButton_clicked()
     
     @pyqtSlot()
     def __installPipUser(self):
@@ -1024,6 +1026,7 @@ class PipPackagesWidget(QWidget, Ui_PipPackagesWidget):
         venvName = self.environmentsComboBox.currentText()
         if venvName:
             self.__pip.installPip(venvName, userSite=True)
+            self.on_refreshButton_clicked()
     
     @pyqtSlot()
     def __repairPip(self):
@@ -1034,6 +1037,7 @@ class PipPackagesWidget(QWidget, Ui_PipPackagesWidget):
         venvName = self.environmentsComboBox.currentText()
         if venvName:
             self.__pip.repairPip(venvName)
+            self.on_refreshButton_clicked()
     
     @pyqtSlot()
     def __installPackages(self):
@@ -1049,6 +1053,7 @@ class PipPackagesWidget(QWidget, Ui_PipPackagesWidget):
                 if packages:
                     self.__pip.installPackages(packages, venvName=venvName,
                                                userSite=user)
+                    self.on_refreshButton_clicked()
     
     @pyqtSlot()
     def __installLocalPackage(self):
@@ -1064,6 +1069,7 @@ class PipPackagesWidget(QWidget, Ui_PipPackagesWidget):
                 if package and os.path.exists(package):
                     self.__pip.installPackages([package], venvName=venvName,
                                                userSite=user)
+                    self.on_refreshButton_clicked()
     
     @pyqtSlot()
     def __installRequirements(self):
@@ -1073,6 +1079,7 @@ class PipPackagesWidget(QWidget, Ui_PipPackagesWidget):
         venvName = self.environmentsComboBox.currentText()
         if venvName:
             self.__pip.installRequirements(venvName)
+            self.on_refreshButton_clicked()
     
     @pyqtSlot()
     def __uninstallRequirements(self):
@@ -1082,6 +1089,7 @@ class PipPackagesWidget(QWidget, Ui_PipPackagesWidget):
         venvName = self.environmentsComboBox.currentText()
         if venvName:
             self.__pip.uninstallRequirements(venvName)
+            self.on_refreshButton_clicked()
     
     @pyqtSlot()
     def __generateRequirements(self):
@@ -1149,7 +1157,7 @@ class PipPackagesWidget(QWidget, Ui_PipPackagesWidget):
             try:
                 with open(cfgFile, "w") as f:
                     f.write("[global]\n")
-            except (IOError, OSError):
+            except OSError:
                 # ignore these
                 pass
         
