@@ -483,7 +483,7 @@ class PluginInstallWidget(QWidget, Ui_PluginInstallDialog):
                     "Error installing plugin. Reason: {0}").format(str(why)),
                 False
             )
-        except IOError as why:
+        except OSError as why:
             self.__rollback()
             return (
                 False,
@@ -600,7 +600,7 @@ class PluginInstallWidget(QWidget, Ui_PluginInstallDialog):
                     os.remove(fnamec)
             
             os.remove(pluginFile)
-        except (IOError, OSError, os.error):
+        except (OSError, os.error):
             # ignore some exceptions
             pass
 
