@@ -208,7 +208,7 @@ class PluginManager(QObject):
                 try:
                     with open(fname, "w"):
                         pass
-                except IOError:
+                except OSError:
                     return (
                         False,
                         self.tr("Could not create a package for {0}.")
@@ -221,7 +221,7 @@ class PluginManager(QObject):
             try:
                 with open(fname, "w"):
                     pass
-            except IOError:
+            except OSError:
                 del self.pluginDirs["user"]
         
         if (
@@ -1203,13 +1203,13 @@ class PluginManager(QObject):
         if not os.path.exists(downloadDir):
             try:
                 os.mkdir(downloadDir, 0o755)
-            except (OSError, IOError):
+            except OSError:
                 # try again with (possibly) new default
                 downloadDir = self.__defaultDownloadDir
                 if not os.path.exists(downloadDir):
                     try:
                         os.mkdir(downloadDir, 0o755)
-                    except (OSError, IOError) as err:
+                    except OSError as err:
                         E5MessageBox.critical(
                             self.__ui,
                             self.tr("Plugin Manager Error"),
