@@ -998,7 +998,7 @@ def PluginRepositoryDownloadCleanup(quiet=False):
         for removeFile in removeFiles:
             try:
                 os.remove(os.path.join(downloadPath, removeFile))
-            except (IOError, OSError) as err:
+            except OSError as err:
                 if not quiet:
                     E5MessageBox.critical(
                         None,
@@ -1027,7 +1027,7 @@ def PluginRepositoryDownloadCleanup(quiet=False):
                     for removeFile in removeFiles:
                         try:
                             os.remove(os.path.join(downloadPath, removeFile))
-                        except (IOError, OSError) as err:
+                        except OSError as err:
                             if not quiet:
                                 E5MessageBox.critical(
                                     None,
