@@ -795,7 +795,7 @@ class CodeStyleCheckerDialog(QDialog, Ui_CodeStyleCheckerDialog):
                 source, encoding = Utilities.readEncodedFile(
                     self.filename)
                 source = source.splitlines(True)
-            except (UnicodeError, IOError) as msg:
+            except (UnicodeError, OSError) as msg:
                 self.results = CodeStyleCheckerDialog.hasResults
                 self.__createFileErrorItem(self.filename, str(msg))
                 self.progress += 1
@@ -843,7 +843,7 @@ class CodeStyleCheckerDialog(QDialog, Ui_CodeStyleCheckerDialog):
                 source, encoding = Utilities.readEncodedFile(
                     filename)
                 source = source.splitlines(True)
-            except (UnicodeError, IOError) as msg:
+            except (UnicodeError, OSError) as msg:
                 self.results = CodeStyleCheckerDialog.hasResults
                 self.__createFileErrorItem(filename, str(msg))
                 continue
@@ -1206,7 +1206,7 @@ class CodeStyleCheckerDialog(QDialog, Ui_CodeStyleCheckerDialog):
             return
         
         if item.parent():
-            fn = Utilities.normabspath(item.data(0, self.filenameRole))
+            fn = os.path.abspath(item.data(0, self.filenameRole))
             lineno = item.data(0, self.lineRole)
             position = item.data(0, self.positionRole)
             message = item.data(0, self.messageRole)
@@ -1246,7 +1246,7 @@ class CodeStyleCheckerDialog(QDialog, Ui_CodeStyleCheckerDialog):
             selectedIndexes = list(range(self.resultList.topLevelItemCount()))
         for index in selectedIndexes:
             itm = self.resultList.topLevelItem(index)
-            fn = Utilities.normabspath(itm.data(0, self.filenameRole))
+            fn = os.path.abspath(itm.data(0, self.filenameRole))
             vm.openSourceFile(fn, 1)
             editor = vm.getOpenEditor(fn)
             editor.clearStyleWarnings()
@@ -1264,7 +1264,7 @@ class CodeStyleCheckerDialog(QDialog, Ui_CodeStyleCheckerDialog):
         for index in range(self.resultList.topLevelItemCount()):
             itm = self.resultList.topLevelItem(index)
             errorFiles.append(
-                Utilities.normabspath(itm.data(0, self.filenameRole)))
+                os.path.abspath(itm.data(0, self.filenameRole)))
         for file in openFiles:
             if file not in errorFiles:
                 editor = vm.getOpenEditor(file)
