@@ -471,9 +471,9 @@ _messages_sample_args = {
     "E742": ["l"],
     "E743": ["l"],
     "E901": ["SyntaxError", "Invalid Syntax"],
-    "E902": ["IOError"],
+    "E902": ["OSError"],
     
-    "FIXWRITE_ERROR": ["IOError"],
+    "FIXWRITE_ERROR": ["OSError"],
 }
 
 messageCatalogs = (
