@@ -2308,7 +2308,7 @@ class GitLogBrowserDialog(QWidget, Ui_GitLogBrowserDialog):
             with open(fname, "w", encoding="utf-8", newline="") as f:
                 f.write(eol.join(self.diffEdit.toPlainText().splitlines()))
                 f.write(eol)
-        except IOError as why:
+        except OSError as why:
             E5MessageBox.critical(
                 self, self.tr('Save Diff'),
                 self.tr(
