@@ -7,7 +7,6 @@
 Module implementing the VCS project helper for Git.
 """
 
-
 import os
 
 from PyQt5.QtCore import QFileInfo
@@ -1601,7 +1600,7 @@ class GitProjectHelper(VcsProjectHelper):
         self.__toolbar.setVisible(False)
         
         ui.registerToolbar("git", self.__toolbar.windowTitle(),
-                           self.__toolbar)
+                           self.__toolbar, "vcs")
         ui.addToolBar(self.__toolbar)
     
     def removeToolbar(self, ui, toolbarManager):
