@@ -7,18 +7,20 @@
 Module implementing a dialog to browse the log history.
 """
 
-
+import re
 import os
 
 import pysvn
 
-from PyQt5.QtCore import QMutexLocker, QDate, QRegExp, Qt, pyqtSlot, QPoint
-from PyQt5.QtGui import QCursor
+from PyQt5.QtCore import Qt, QDate, pyqtSlot, QPoint
 from PyQt5.QtWidgets import (
     QHeaderView, QWidget, QApplication, QDialogButtonBox, QTreeWidgetItem
 )
 
 from E5Gui import E5MessageBox
+from E5Gui.E5OverrideCursor import E5OverrideCursor
+
+from E5Utilities.E5MutexLocker import E5MutexLocker
 
 from .SvnUtilities import formatTime, dateFromTime_t
 from .SvnDialogMixin import SvnDialogMixin
@@ -264,9 +266,6 @@ class SvnLogBrowserDialog(QWidget, SvnDialogMixin, Ui_SvnLogBrowserDialog):
         fetchLimit = 10
         self._reset()
         
-        QApplication.setOverrideCursor(QCursor(Qt.WaitCursor))
-        QApplication.processEvents()
-        
         limit = self.limitSpinBox.value()
         if startRev is None:
             start = pysvn.Revision(pysvn.opt_revision_kind.head)
@@ -277,70 +276,72 @@ class SvnLogBrowserDialog(QWidget, SvnDialogMixin, Ui_SvnLogBrowserDialog):
             except TypeError:
                 start = pysvn.Revision(pysvn.opt_revision_kind.head)
         
-        locker = QMutexLocker(self.vcs.vcsExecutionMutex)
-        cwd = os.getcwd()
-        os.chdir(self.dname)
-        try:
-            nextRev = 0
-            fetched = 0
-            logs = []
-            while fetched < limit:
-                flimit = min(fetchLimit, limit - fetched)
-                if fetched == 0:
-                    revstart = start
-                else:
-                    revstart = pysvn.Revision(
-                        pysvn.opt_revision_kind.number, nextRev)
-                allLogs = self.client.log(
-                    self.fname, revision_start=revstart,
-                    discover_changed_paths=True, limit=flimit + 1,
-                    strict_node_history=self.stopCheckBox.isChecked())
-                if len(allLogs) <= flimit or self._clientCancelCallback():
-                    logs.extend(allLogs)
-                    break
-                else:
-                    logs.extend(allLogs[:-1])
-                    nextRev = allLogs[-1]["revision"].number
-                    fetched += fetchLimit
-            locker.unlock()
-            
-            for log in logs:
-                author = log["author"]
-                message = log["message"]
-                self.__generateLogItem(
-                    author, log["date"], message,
-                    log["revision"], log['changed_paths'])
-                dt = dateFromTime_t(log["date"])
-                if (
-                    not self.__maxDate.isValid() and
-                    not self.__minDate.isValid()
-                ):
-                    self.__maxDate = dt
-                    self.__minDate = dt
-                else:
-                    if self.__maxDate < dt:
+        with E5OverrideCursor():
+            cwd = os.getcwd()
+            os.chdir(self.dname)
+            try:
+                nextRev = 0
+                fetched = 0
+                logs = []
+                with E5MutexLocker(self.vcs.vcsExecutionMutex):
+                    while fetched < limit:
+                        flimit = min(fetchLimit, limit - fetched)
+                        if fetched == 0:
+                            revstart = start
+                        else:
+                            revstart = pysvn.Revision(
+                                pysvn.opt_revision_kind.number, nextRev)
+                        allLogs = self.client.log(
+                            self.fname, revision_start=revstart,
+                            discover_changed_paths=True, limit=flimit + 1,
+                            strict_node_history=self.stopCheckBox.isChecked())
+                        if (
+                            len(allLogs) <= flimit or
+                            self._clientCancelCallback()
+                        ):
+                            logs.extend(allLogs)
+                            break
+                        else:
+                            logs.extend(allLogs[:-1])
+                            nextRev = allLogs[-1]["revision"].number
+                            fetched += fetchLimit
+                
+                for log in logs:
+                    author = log["author"]
+                    message = log["message"]
+                    self.__generateLogItem(
+                        author, log["date"], message,
+                        log["revision"], log['changed_paths'])
+                    dt = dateFromTime_t(log["date"])
+                    if (
+                        not self.__maxDate.isValid() and
+                        not self.__minDate.isValid()
+                    ):
                         self.__maxDate = dt
-                    if self.__minDate > dt:
                         self.__minDate = dt
-            if len(logs) < limit and not self.cancelled:
-                self.nextButton.setEnabled(False)
-                self.limitSpinBox.setEnabled(False)
-            self.__filterLogsEnabled = False
-            self.fromDate.setMinimumDate(self.__minDate)
-            self.fromDate.setMaximumDate(self.__maxDate)
-            self.fromDate.setDate(self.__minDate)
-            self.toDate.setMinimumDate(self.__minDate)
-            self.toDate.setMaximumDate(self.__maxDate)
-            self.toDate.setDate(self.__maxDate)
-            self.__filterLogsEnabled = True
-            
-            self.__resizeColumnsLog()
-            self.__resortLog()
-            self.__filterLogs()
-        except pysvn.ClientError as e:
-            locker.unlock()
-            self.__showError(e.args[0])
-        os.chdir(cwd)
+                    else:
+                        if self.__maxDate < dt:
+                            self.__maxDate = dt
+                        if self.__minDate > dt:
+                            self.__minDate = dt
+                if len(logs) < limit and not self.cancelled:
+                    self.nextButton.setEnabled(False)
+                    self.limitSpinBox.setEnabled(False)
+                self.__filterLogsEnabled = False
+                self.fromDate.setMinimumDate(self.__minDate)
+                self.fromDate.setMaximumDate(self.__maxDate)
+                self.fromDate.setDate(self.__minDate)
+                self.toDate.setMinimumDate(self.__minDate)
+                self.toDate.setMaximumDate(self.__maxDate)
+                self.toDate.setDate(self.__maxDate)
+                self.__filterLogsEnabled = True
+                
+                self.__resizeColumnsLog()
+                self.__resortLog()
+                self.__filterLogs()
+            except pysvn.ClientError as e:
+                self.__showError(e.args[0])
+            os.chdir(cwd)
         self.__finish()
     
     def start(self, fn, isFile=False):
@@ -370,8 +371,6 @@ class SvnLogBrowserDialog(QWidget, SvnDialogMixin, Ui_SvnLogBrowserDialog):
         """
         Private slot called when the user pressed the button.
         """
-        QApplication.restoreOverrideCursor()
-        
         self.buttonBox.button(QDialogButtonBox.Close).setEnabled(True)
         self.buttonBox.button(QDialogButtonBox.Cancel).setEnabled(False)
         self.buttonBox.button(QDialogButtonBox.Close).setDefault(True)
@@ -568,18 +567,18 @@ class SvnLogBrowserDialog(QWidget, SvnDialogMixin, Ui_SvnLogBrowserDialog):
             txt = self.fieldCombo.currentText()
             if txt == self.tr("Author"):
                 fieldIndex = 1
-                searchRx = QRegExp(self.rxEdit.text(), Qt.CaseInsensitive)
+                searchRx = re.compile(self.rxEdit.text(), re.IGNORECASE)
             elif txt == self.tr("Revision"):
                 fieldIndex = 0
                 txt = self.rxEdit.text()
                 if txt.startswith("^"):
-                    searchRx = QRegExp(
-                        r"^\s*{0}".format(txt[1:]), Qt.CaseInsensitive)
+                    searchRx = re.compile(
+                        r"^\s*{0}".format(txt[1:]), re.IGNORECASE)
                 else:
-                    searchRx = QRegExp(txt, Qt.CaseInsensitive)
+                    searchRx = re.compile(txt, re.IGNORECASE)
             else:
                 fieldIndex = 3
-                searchRx = QRegExp(self.rxEdit.text(), Qt.CaseInsensitive)
+                searchRx = re.compile(self.rxEdit.text(), re.IGNORECASE)
             
             currentItem = self.logTree.currentItem()
             for topIndex in range(self.logTree.topLevelItemCount()):
@@ -587,7 +586,7 @@ class SvnLogBrowserDialog(QWidget, SvnDialogMixin, Ui_SvnLogBrowserDialog):
                 if (
                     topItem.text(2) <= to_ and
                     topItem.text(2) >= from_ and
-                    searchRx.indexIn(topItem.text(fieldIndex)) > -1
+                    searchRx.search(topItem.text(fieldIndex)) is not None
                 ):
                     topItem.setHidden(False)
                     if topItem is currentItem:
