@@ -1,26 +1,26 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2006 - 2019 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2006 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the version control systems interface to Subversion.
 """
 
-
+import re
 import os
 import shutil
 import time
 from urllib.parse import quote
 
-from PyQt5.QtCore import (
-    Qt, QMutexLocker, pyqtSignal, QRegExp, QDateTime, QCoreApplication
-)
+from PyQt5.QtCore import pyqtSignal, Qt, QDateTime, QCoreApplication
 from PyQt5.QtWidgets import QLineEdit, QDialog, QInputDialog, QApplication
 
 from E5Gui.E5Application import e5App
 from E5Gui import E5MessageBox
 
+from E5Utilities.E5MutexLocker import E5MutexLocker
+
 from VCS.VersionControl import VersionControl
 
 import pysvn
@@ -301,7 +301,6 @@ class Subversion(VersionControl):
                 shutil.rmtree(tmpDir, True)
             return False, False
         
-        locker = QMutexLocker(self.vcsExecutionMutex)
         cwd = os.getcwd()
         os.chdir(os.path.join(tmpDir, project))
         opts = self.options['global']
@@ -316,19 +315,19 @@ class Subversion(VersionControl):
                 client)
             QApplication.processEvents()
         try:
-            rev = client.import_(".", url, msg, recurse, ignore=True)
+            with E5MutexLocker(self.vcsExecutionMutex):
+                rev = client.import_(".", url, msg, recurse, ignore=True)
             status = True
         except pysvn.ClientError as e:
             status = False
             rev = None
             if not noDialog:
                 dlg.showError(e.args[0])
-        locker.unlock()
         if not noDialog:
             rev and dlg.showMessage(self.tr("Imported revision {0}.\n")
                                     .format(rev.number))
             dlg.finish()
-            dlg.exec_()
+            dlg.exec()
         os.chdir(cwd)
         
         shutil.rmtree(tmpDir, True)
@@ -391,18 +390,17 @@ class Subversion(VersionControl):
                     url, projectDir),
                 client)
             QApplication.processEvents()
-        locker = QMutexLocker(self.vcsExecutionMutex)
         try:
-            client.checkout(url, projectDir, recurse)
+            with E5MutexLocker(self.vcsExecutionMutex):
+                client.checkout(url, projectDir, recurse)
             status = True
         except pysvn.ClientError as e:
             status = False
             if not noDialog:
                 dlg.showError(e.args[0])
-        locker.unlock()
         if not noDialog:
             dlg.finish()
-            dlg.exec_()
+            dlg.exec()
         return status
         
     def vcsExport(self, vcsDataDict, projectDir):
@@ -457,16 +455,15 @@ class Subversion(VersionControl):
                 url, projectDir),
             client)
         QApplication.processEvents()
-        locker = QMutexLocker(self.vcsExecutionMutex)
         try:
-            client.export(url, projectDir, force=True, recurse=recurse)
+            with E5MutexLocker(self.vcsExecutionMutex):
+                client.export(url, projectDir, force=True, recurse=recurse)
             status = True
         except pysvn.ClientError as e:
             status = False
             dlg.showError(e.args[0])
-        locker.unlock()
         dlg.finish()
-        dlg.exec_()
+        dlg.exec()
         return status
         
     def vcsCommit(self, name, message, noDialog=False):
@@ -567,7 +564,6 @@ class Subversion(VersionControl):
         ):
             noDialog = False
         
-        locker = QMutexLocker(self.vcsExecutionMutex)
         cwd = os.getcwd()
         os.chdir(dname)
         opts = self.options['global'] + self.options['commit']
@@ -587,24 +583,24 @@ class Subversion(VersionControl):
                 client)
             QApplication.processEvents()
         try:
-            if changelists:
-                rev = client.checkin(fnames, msg,
-                                     recurse=recurse, keep_locks=keeplocks,
-                                     keep_changelist=keepChangelists,
-                                     changelists=changelists)
-            else:
-                rev = client.checkin(fnames, msg,
-                                     recurse=recurse, keep_locks=keeplocks)
+            with E5MutexLocker(self.vcsExecutionMutex):
+                if changelists:
+                    rev = client.checkin(fnames, msg,
+                                         recurse=recurse, keep_locks=keeplocks,
+                                         keep_changelist=keepChangelists,
+                                         changelists=changelists)
+                else:
+                    rev = client.checkin(fnames, msg,
+                                         recurse=recurse, keep_locks=keeplocks)
         except pysvn.ClientError as e:
             rev = None
             if not noDialog:
                 dlg.showError(e.args[0])
-        locker.unlock()
         if not noDialog:
             rev and dlg.showMessage(self.tr("Committed revision {0}.")
                                     .format(rev.number))
             dlg.finish()
-            dlg.exec_()
+            dlg.exec()
         os.chdir(cwd)
         self.committed.emit()
         self.checkVCSStatus()
@@ -626,7 +622,6 @@ class Subversion(VersionControl):
             dname, fname = self.splitPath(name)
             fnames = [fname]
         
-        locker = QMutexLocker(self.vcsExecutionMutex)
         cwd = os.getcwd()
         os.chdir(dname)
         opts = self.options['global'] + self.options['update']
@@ -641,13 +636,13 @@ class Subversion(VersionControl):
                 client)
         QApplication.processEvents()
         try:
-            client.update(fnames, recurse)
+            with E5MutexLocker(self.vcsExecutionMutex):
+                client.update(fnames, recurse)
         except pysvn.ClientError as e:
             dlg.showError(e.args[0])
-        locker.unlock()
         if not noDialog:
             dlg.finish()
-            dlg.exec_()
+            dlg.exec()
             res = dlg.hasAddOrDelete()
         else:
             res = False
@@ -735,7 +730,6 @@ class Subversion(VersionControl):
         else:
             names.append(name)
         
-        locker = QMutexLocker(self.vcsExecutionMutex)
         cwd = os.getcwd()
         os.chdir(wdir)
         opts = self.options['global'] + self.options['add']
@@ -754,15 +748,15 @@ class Subversion(VersionControl):
                 client)
             QApplication.processEvents()
         try:
-            client.add(names, recurse=recurse, force=force,
-                       ignore=not noignore)
+            with E5MutexLocker(self.vcsExecutionMutex):
+                client.add(names, recurse=recurse, force=force,
+                           ignore=not noignore)
         except pysvn.ClientError as e:
             if not noDialog:
                 dlg.showError(e.args[0])
-        locker.unlock()
         if not noDialog:
             dlg.finish()
-            dlg.exec_()
+            dlg.exec()
         os.chdir(cwd)
         
     def vcsAddBinary(self, name, isDir=False):
@@ -846,7 +840,6 @@ class Subversion(VersionControl):
         else:
             names.append(path)
         
-        locker = QMutexLocker(self.vcsExecutionMutex)
         cwd = os.getcwd()
         os.chdir(dname)
         opts = self.options['global'] + self.options['add']
@@ -863,12 +856,12 @@ class Subversion(VersionControl):
             client)
         QApplication.processEvents()
         try:
-            client.add(names, recurse=recurse, force=force, ignore=ignore)
+            with E5MutexLocker(self.vcsExecutionMutex):
+                client.add(names, recurse=recurse, force=force, ignore=ignore)
         except pysvn.ClientError as e:
             dlg.showError(e.args[0])
-        locker.unlock()
         dlg.finish()
-        dlg.exec_()
+        dlg.exec()
         os.chdir(cwd)
         
     def vcsRemove(self, name, project=False, noDialog=False):
@@ -899,18 +892,17 @@ class Subversion(VersionControl):
                     " ".join(name)),
                 client)
             QApplication.processEvents()
-        locker = QMutexLocker(self.vcsExecutionMutex)
         try:
-            client.remove(name, force=force)
+            with E5MutexLocker(self.vcsExecutionMutex):
+                client.remove(name, force=force)
             res = True
         except pysvn.ClientError as e:
             res = False
             if not noDialog:
                 dlg.showError(e.args[0])
-        locker.unlock()
         if not noDialog:
             dlg.finish()
-            dlg.exec_()
+            dlg.exec()
         
         return res
         
@@ -924,7 +916,7 @@ class Subversion(VersionControl):
         @param noDialog flag indicating quiet operations
         @return flag indicating successfull operation (boolean)
         """
-        rx_prot = QRegExp('(file:|svn:|svn+ssh:|http:|https:).+')
+        rx_prot = re.compile('(file:|svn:|svn+ssh:|http:|https:).+')
         opts = self.options['global']
         res = False
         
@@ -936,20 +928,20 @@ class Subversion(VersionControl):
         else:
             from .SvnCopyDialog import SvnCopyDialog
             dlg = SvnCopyDialog(name, None, True, "--force" in opts)
-            accepted = (dlg.exec_() == QDialog.Accepted)
+            accepted = (dlg.exec() == QDialog.Accepted)
             if accepted:
                 target, force = dlg.getData()
             if not target:
                 return False
         
-        if not rx_prot.exactMatch(target):
+        if rx_prot.fullmatch(target) is None:
             isDir = os.path.isdir(name)
         else:
             isDir = False
         
         if accepted:
             client = self.getClient()
-            if rx_prot.exactMatch(target):
+            if rx_prot.fullmatch(target) is not None:
                 target = self.__svnURL(target)
                 log = "Moving {0} to {1}".format(name, target)
             else:
@@ -964,19 +956,18 @@ class Subversion(VersionControl):
                         name, target),
                     client, log=log)
                 QApplication.processEvents()
-            locker = QMutexLocker(self.vcsExecutionMutex)
             try:
-                client.move(name, target, force=force)
+                with E5MutexLocker(self.vcsExecutionMutex):
+                    client.move(name, target, force=force)
                 res = True
             except pysvn.ClientError as e:
                 res = False
                 if not noDialog:
                     dlg.showError(e.args[0])
-            locker.unlock()
             if not noDialog:
                 dlg.finish()
-                dlg.exec_()
-            if res and not rx_prot.exactMatch(target):
+                dlg.exec()
+            if res and rx_prot.fullmatch(target) is None:
                 if target.startswith(project.getProjectPath()):
                     if isDir:
                         project.moveDirectory(name, target)
@@ -1065,7 +1056,7 @@ class Subversion(VersionControl):
         from .SvnTagDialog import SvnTagDialog
         dlg = SvnTagDialog(self.allTagsBranchesList, url,
                            self.otherData["standardLayout"])
-        if dlg.exec_() == QDialog.Accepted:
+        if dlg.exec() == QDialog.Accepted:
             tag, tagOp = dlg.getParameters()
             if tag in self.allTagsBranchesList:
                 self.allTagsBranchesList.remove(tag)
@@ -1074,8 +1065,10 @@ class Subversion(VersionControl):
             return
         
         if self.otherData["standardLayout"]:
-            rx_base = QRegExp('(.+)/(trunk|tags|branches).*')
-            if not rx_base.exactMatch(reposURL):
+            rx_base = re.compile('(.+)/(trunk|tags|branches).*')
+            
+            match = rx_base.fullmatch(reposURL)
+            if match is None:
                 E5MessageBox.critical(
                     self.__ui,
                     self.tr("Subversion Error"),
@@ -1085,7 +1078,7 @@ class Subversion(VersionControl):
                         """ be aborted"""))
                 return
             
-            reposRoot = rx_base.cap(1)
+            reposRoot = match.group(1)
             if tagOp in [1, 4]:
                 url = '{0}/tags/{1}'.format(reposRoot, quote(tag))
             elif tagOp in [2, 8]:
@@ -1104,12 +1097,11 @@ class Subversion(VersionControl):
                 "copy --message {0} {1} {2}".format(log, reposURL, url),
                 client, log=log)
             QApplication.processEvents()
-            locker = QMutexLocker(self.vcsExecutionMutex)
             try:
-                rev = client.copy(reposURL, url)
+                with E5MutexLocker(self.vcsExecutionMutex):
+                    rev = client.copy(reposURL, url)
             except pysvn.ClientError as e:
                 dlg.showError(e.args[0])
-            locker.unlock()
         else:
             log = 'Deleted tag <{0}>'.format(self.tagName)
             dlg = SvnDialog(
@@ -1118,16 +1110,15 @@ class Subversion(VersionControl):
                 "remove --message {0} {1}".format(log, url),
                 client, log=log)
             QApplication.processEvents()
-            locker = QMutexLocker(self.vcsExecutionMutex)
             try:
-                rev = client.remove(url)
+                with E5MutexLocker(self.vcsExecutionMutex):
+                    rev = client.remove(url)
             except pysvn.ClientError as e:
                 dlg.showError(e.args[0])
-            locker.unlock()
         rev and dlg.showMessage(
             self.tr("Revision {0}.\n").format(rev.number))
         dlg.finish()
-        dlg.exec_()
+        dlg.exec()
         
     def vcsRevert(self, name):
         """
@@ -1154,7 +1145,7 @@ class Subversion(VersionControl):
                     "Do you really want to revert all changes to these files"
                     " or directories?"),
                 name)
-            yes = dia.exec_() == QDialog.Accepted
+            yes = dia.exec() == QDialog.Accepted
         else:
             yes = E5MessageBox.yesNo(
                 None,
@@ -1170,14 +1161,13 @@ class Subversion(VersionControl):
                     " ".join(name)),
                 client)
             QApplication.processEvents()
-            locker = QMutexLocker(self.vcsExecutionMutex)
             try:
-                client.revert(name, recurse)
+                with E5MutexLocker(self.vcsExecutionMutex):
+                    client.revert(name, recurse)
             except pysvn.ClientError as e:
                 dlg.showError(e.args[0])
-            locker.unlock()
             dlg.finish()
-            dlg.exec_()
+            dlg.exec()
             self.checkVCSStatus()
     
     def vcsSwitch(self, name):
@@ -1208,7 +1198,7 @@ class Subversion(VersionControl):
         from .SvnSwitchDialog import SvnSwitchDialog
         dlg = SvnSwitchDialog(self.allTagsBranchesList, url,
                               self.otherData["standardLayout"])
-        if dlg.exec_() == QDialog.Accepted:
+        if dlg.exec() == QDialog.Accepted:
             tag, tagType = dlg.getParameters()
             if tag in self.allTagsBranchesList:
                 self.allTagsBranchesList.remove(tag)
@@ -1217,8 +1207,9 @@ class Subversion(VersionControl):
             return False
         
         if self.otherData["standardLayout"]:
-            rx_base = QRegExp('(.+)/(trunk|tags|branches).*')
-            if not rx_base.exactMatch(reposURL):
+            rx_base = re.compile('(.+)/(trunk|tags|branches).*')
+            match = rx_base.fullmatch(reposURL)
+            if match is None:
                 E5MessageBox.critical(
                     self.__ui,
                     self.tr("Subversion Error"),
@@ -1228,7 +1219,7 @@ class Subversion(VersionControl):
                         """ be aborted"""))
                 return False
             
-            reposRoot = rx_base.cap(1)
+            reposRoot = match.group(1)
             tn = tag
             if tagType == 1:
                 url = '{0}/tags/{1}'.format(reposRoot, quote(tag))
@@ -1246,15 +1237,14 @@ class Subversion(VersionControl):
                         "switch {0} {1}".format(url, name),
                         client)
         QApplication.processEvents()
-        locker = QMutexLocker(self.vcsExecutionMutex)
         try:
-            rev = client.switch(name, url)
+            with E5MutexLocker(self.vcsExecutionMutex):
+                rev = client.switch(name, url)
             dlg.showMessage(self.tr("Revision {0}.\n").format(rev.number))
         except pysvn.ClientError as e:
             dlg.showError(e.args[0])
-        locker.unlock()
         dlg.finish()
-        dlg.exec_()
+        dlg.exec()
         res = dlg.hasAddOrDelete()
         self.checkVCSStatus()
         return res
@@ -1271,7 +1261,7 @@ class Subversion(VersionControl):
         from .SvnMergeDialog import SvnMergeDialog
         dlg = SvnMergeDialog(self.mergeList[0], self.mergeList[1],
                              self.mergeList[2], "--force" in opts)
-        if dlg.exec_() == QDialog.Accepted:
+        if dlg.exec() == QDialog.Accepted:
             urlrev1, urlrev2, target, force = dlg.getParameters()
         else:
             return
@@ -1284,13 +1274,12 @@ class Subversion(VersionControl):
             self.mergeList[1].remove(urlrev2)
         self.mergeList[1].insert(0, urlrev2)
         
-        rx_rev = QRegExp('\\d+|HEAD|head')
+        rx_rev = re.compile('\\d+|HEAD|head')
         
-        locker = QMutexLocker(self.vcsExecutionMutex)
         cwd = os.getcwd()
         os.chdir(dname)
         recurse = "--non-recursive" not in opts
-        if rx_rev.exactMatch(urlrev1):
+        if bool(rx_rev.fullmatch(urlrev1)):
             if urlrev1 in ["HEAD", "head"]:
                 revision1 = pysvn.Revision(pysvn.opt_revision_kind.head)
                 rev1 = "HEAD"
@@ -1355,13 +1344,13 @@ class Subversion(VersionControl):
             client)
         QApplication.processEvents()
         try:
-            client.merge(url1, revision1, url2, revision2, fname,
-                         recurse=recurse, force=force)
+            with E5MutexLocker(self.vcsExecutionMutex):
+                client.merge(url1, revision1, url2, revision2, fname,
+                             recurse=recurse, force=force)
         except pysvn.ClientError as e:
             dlg.showError(e.args[0])
-        locker.unlock()
         dlg.finish()
-        dlg.exec_()
+        dlg.exec()
         os.chdir(cwd)
         
     def vcsRegisteredState(self, name):
@@ -1496,13 +1485,11 @@ class Subversion(VersionControl):
             )
             
             try:
-                locker = QMutexLocker(self.vcsExecutionMutex)
-                allFiles = client.status(dname, recurse=True, get_all=True,
-                                         ignore=True, update=False)
-                locker.unlock()
+                with E5MutexLocker(self.vcsExecutionMutex):
+                    allFiles = client.status(dname, recurse=True, get_all=True,
+                                             ignore=True, update=False)
                 dirs = [x for x in names.keys() if os.path.isdir(x)]
                 for file in allFiles:
-                    # file.path is always unicode in Python 2
                     name = os.path.normcase(file.path)
                     if self.__isVersioned(file):
                         if name in names:
@@ -1531,7 +1518,8 @@ class Subversion(VersionControl):
                     else:
                         self.statusCache[name] = self.canBeAdded
             except pysvn.ClientError:
-                locker.unlock()    # ignore pysvn errors
+                # ignore pysvn errors
+                pass
         
         return names
         
@@ -1577,12 +1565,10 @@ class Subversion(VersionControl):
             )
             
             try:
-                locker = QMutexLocker(self.vcsExecutionMutex)
-                allFiles = client.status(dname, recurse=True, get_all=True,
-                                         ignore=True, update=False)
-                locker.unlock()
+                with E5MutexLocker(self.vcsExecutionMutex):
+                    allFiles = client.status(dname, recurse=True, get_all=True,
+                                             ignore=True, update=False)
                 for file in allFiles:
-                    # file.path is always unicode in Python 2
                     name = os.path.normcase(file.path)
                     if self.__isVersioned(file):
                         if name in names:
@@ -1591,7 +1577,8 @@ class Subversion(VersionControl):
                     else:
                         self.statusCache[name] = self.canBeAdded
             except pysvn.ClientError:
-                locker.unlock()    # ignore pysvn errors
+                # ignore pysvn errors
+                pass
         
         return names
         
@@ -1654,14 +1641,13 @@ class Subversion(VersionControl):
                         "cleanup {0}".format(name),
                         client)
         QApplication.processEvents()
-        locker = QMutexLocker(self.vcsExecutionMutex)
         try:
-            client.cleanup(name)
+            with E5MutexLocker(self.vcsExecutionMutex):
+                client.cleanup(name)
         except pysvn.ClientError as e:
             dlg.showError(e.args[0])
-        locker.unlock()
         dlg.finish()
-        dlg.exec_()
+        dlg.exec()
     
     def vcsCommandLine(self, name):
         """
@@ -1671,7 +1657,7 @@ class Subversion(VersionControl):
         """
         from .SvnCommandDialog import SvnCommandDialog
         dlg = SvnCommandDialog(self.commandHistory, self.wdHistory, name)
-        if dlg.exec_() == QDialog.Accepted:
+        if dlg.exec() == QDialog.Accepted:
             command, wd = dlg.getData()
             commandList = Utilities.parseOptionString(command)
             
@@ -1693,7 +1679,7 @@ class Subversion(VersionControl):
             dia = SvnProcessDialog(self.tr('Subversion command'))
             res = dia.startProcess(args, wd)
             if res:
-                dia.exec_()
+                dia.exec()
         
     def vcsOptionsDialog(self, project, archive, editable=False, parent=None):
         """
@@ -1781,13 +1767,12 @@ class Subversion(VersionControl):
         @return string with the repository path URL
         """
         client = pysvn.Client()
-        locker = QMutexLocker(self.vcsExecutionMutex)
         try:
-            entry = client.info(path)
+            with E5MutexLocker(self.vcsExecutionMutex):
+                entry = client.info(path)
             url = entry.url
         except pysvn.ClientError:
             url = ""
-        locker.unlock()
         return url
 
     def svnResolve(self, name):
@@ -1802,7 +1787,6 @@ class Subversion(VersionControl):
             dname, fname = self.splitPath(name)
             fnames = [fname]
         
-        locker = QMutexLocker(self.vcsExecutionMutex)
         cwd = os.getcwd()
         os.chdir(dname)
         opts = self.options['global']
@@ -1815,13 +1799,13 @@ class Subversion(VersionControl):
                         client)
         QApplication.processEvents()
         try:
-            for name in fnames:
-                client.resolved(name, recurse=recurse)
+            with E5MutexLocker(self.vcsExecutionMutex):
+                for name in fnames:
+                    client.resolved(name, recurse=recurse)
         except pysvn.ClientError as e:
             dlg.showError(e.args[0])
-        locker.unlock()
         dlg.finish()
-        dlg.exec_()
+        dlg.exec()
         os.chdir(cwd)
         self.checkVCSStatus()
     
@@ -1834,14 +1818,14 @@ class Subversion(VersionControl):
         @return flag indicating successfull operation (boolean)
         """
         from .SvnCopyDialog import SvnCopyDialog
-        rx_prot = QRegExp('(file:|svn:|svn+ssh:|http:|https:).+')
+        rx_prot = re.compile('(file:|svn:|svn+ssh:|http:|https:).+')
         dlg = SvnCopyDialog(name)
         res = False
-        if dlg.exec_() == QDialog.Accepted:
+        if dlg.exec() == QDialog.Accepted:
             target, force = dlg.getData()
             
             client = self.getClient()
-            if rx_prot.exactMatch(target):
+            if bool(rx_prot.fullmatch(target)):
                 target = self.__svnURL(target)
                 log = "Copying {0} to {1}".format(name, target)
             else:
@@ -1854,19 +1838,18 @@ class Subversion(VersionControl):
                     name, target),
                 client, log=log)
             QApplication.processEvents()
-            locker = QMutexLocker(self.vcsExecutionMutex)
             try:
-                client.copy(name, target)
+                with E5MutexLocker(self.vcsExecutionMutex):
+                    client.copy(name, target)
                 res = True
             except pysvn.ClientError as e:
                 res = False
                 dlg.showError(e.args[0])
-            locker.unlock()
             dlg.finish()
-            dlg.exec_()
+            dlg.exec()
             if (
                 res and
-                not rx_prot.exactMatch(target) and
+                not bool(rx_prot.fullmatch(target)) and
                 target.startswith(project.getProjectPath())
             ):
                 if os.path.isdir(name):
@@ -1899,7 +1882,7 @@ class Subversion(VersionControl):
         """
         from .SvnPropSetDialog import SvnPropSetDialog
         dlg = SvnPropSetDialog(recursive)
-        if dlg.exec_() == QDialog.Accepted:
+        if dlg.exec() == QDialog.Accepted:
             propName, propValue, recurse = dlg.getData()
             if not propName:
                 E5MessageBox.critical(
@@ -1915,7 +1898,6 @@ class Subversion(VersionControl):
                 dname, fname = self.splitPath(name)
                 fnames = [fname]
             
-            locker = QMutexLocker(self.vcsExecutionMutex)
             cwd = os.getcwd()
             os.chdir(dname)
             opts = self.options['global']
@@ -1931,15 +1913,15 @@ class Subversion(VersionControl):
                 client)
             QApplication.processEvents()
             try:
-                for name in fnames:
-                    client.propset(propName, propValue, name,
-                                   recurse=recurse, skip_checks=skipchecks)
+                with E5MutexLocker(self.vcsExecutionMutex):
+                    for name in fnames:
+                        client.propset(propName, propValue, name,
+                                       recurse=recurse, skip_checks=skipchecks)
             except pysvn.ClientError as e:
                 dlg.showError(e.args[0])
-            locker.unlock()
             dlg.showMessage(self.tr("Property set."))
             dlg.finish()
-            dlg.exec_()
+            dlg.exec()
             os.chdir(cwd)
         
     def svnDelProp(self, name, recursive=False):
@@ -1951,7 +1933,7 @@ class Subversion(VersionControl):
         """
         from .SvnPropDelDialog import SvnPropDelDialog
         dlg = SvnPropDelDialog(recursive)
-        if dlg.exec_() == QDialog.Accepted:
+        if dlg.exec() == QDialog.Accepted:
             propName, recurse = dlg.getData()
             
             if not propName:
@@ -1968,7 +1950,6 @@ class Subversion(VersionControl):
                 dname, fname = self.splitPath(name)
                 fnames = [fname]
             
-            locker = QMutexLocker(self.vcsExecutionMutex)
             cwd = os.getcwd()
             os.chdir(dname)
             opts = self.options['global']
@@ -1983,15 +1964,15 @@ class Subversion(VersionControl):
                 client)
             QApplication.processEvents()
             try:
-                for name in fnames:
-                    client.propdel(propName, name,
-                                   recurse=recurse, skip_checks=skipchecks)
+                with E5MutexLocker(self.vcsExecutionMutex):
+                    for name in fnames:
+                        client.propdel(propName, name,
+                                       recurse=recurse, skip_checks=skipchecks)
             except pysvn.ClientError as e:
                 dlg.showError(e.args[0])
-            locker.unlock()
             dlg.showMessage(self.tr("Property deleted."))
             dlg.finish()
-            dlg.exec_()
+            dlg.exec()
             os.chdir(cwd)
         
     def svnListTagBranch(self, path, tags=True):
@@ -2070,7 +2051,7 @@ class Subversion(VersionControl):
                     return
         from .SvnRevisionSelectionDialog import SvnRevisionSelectionDialog
         dlg = SvnRevisionSelectionDialog()
-        if dlg.exec_() == QDialog.Accepted:
+        if dlg.exec() == QDialog.Accepted:
             revisions = dlg.getRevisions()
             if self.diff is None:
                 from .SvnDiffDialog import SvnDiffDialog
@@ -2113,7 +2094,7 @@ class Subversion(VersionControl):
         from .SvnUrlSelectionDialog import SvnUrlSelectionDialog
         dlg = SvnUrlSelectionDialog(self, self.tagsList, self.branchesList,
                                     dname)
-        if dlg.exec_() == QDialog.Accepted:
+        if dlg.exec() == QDialog.Accepted:
             urls, summary = dlg.getURLs()
             if self.diff is None:
                 from .SvnDiffDialog import SvnDiffDialog
@@ -2182,7 +2163,7 @@ class Subversion(VersionControl):
         if extended:
             from .SvnRevisionSelectionDialog import SvnRevisionSelectionDialog
             dlg = SvnRevisionSelectionDialog()
-            if dlg.exec_() == QDialog.Accepted:
+            if dlg.exec() == QDialog.Accepted:
                 rev1, rev2 = dlg.getRevisions()
                 if rev1 == "WORKING":
                     rev1 = ""
@@ -2215,11 +2196,10 @@ class Subversion(VersionControl):
             name2 = "{0} (rev. {1})".format(name, rev2)
         else:
             try:
-                f1 = open(name, "r", encoding="utf-8")
-                output2 = f1.read()
-                f1.close()
+                with open(name, "r", encoding="utf-8") as f1:
+                    output2 = f1.read()
                 name2 = name
-            except IOError:
+            except OSError:
                 E5MessageBox.critical(
                     self.__ui,
                     self.tr("Subversion Side-by-Side Difference"),
@@ -2276,7 +2256,6 @@ class Subversion(VersionControl):
             dname, fname = self.splitPath(name)
             fnames = [fname]
         
-        locker = QMutexLocker(self.vcsExecutionMutex)
         cwd = os.getcwd()
         os.chdir(dname)
         client = self.getClient()
@@ -2289,14 +2268,14 @@ class Subversion(VersionControl):
             client, parent=parent)
         QApplication.processEvents()
         try:
-            client.lock(fnames, comment, force=stealIt)
+            with E5MutexLocker(self.vcsExecutionMutex):
+                client.lock(fnames, comment, force=stealIt)
         except pysvn.ClientError as e:
             dlg.showError(e.args[0])
         except AttributeError as e:
             dlg.showError(str(e))
-        locker.unlock()
         dlg.finish()
-        dlg.exec_()
+        dlg.exec()
         os.chdir(cwd)
         
     def svnUnlock(self, name, breakIt=False, parent=None):
@@ -2315,7 +2294,6 @@ class Subversion(VersionControl):
             dname, fname = self.splitPath(name)
             fnames = [fname]
         
-        locker = QMutexLocker(self.vcsExecutionMutex)
         cwd = os.getcwd()
         os.chdir(dname)
         client = self.getClient()
@@ -2326,14 +2304,14 @@ class Subversion(VersionControl):
             client, parent=parent)
         QApplication.processEvents()
         try:
-            client.unlock(fnames, force=breakIt)
+            with E5MutexLocker(self.vcsExecutionMutex):
+                client.unlock(fnames, force=breakIt)
         except pysvn.ClientError as e:
             dlg.showError(e.args[0])
         except AttributeError as e:
             dlg.showError(str(e))
-        locker.unlock()
         dlg.finish()
-        dlg.exec_()
+        dlg.exec()
         os.chdir(cwd)
         
     def svnInfo(self, projectPath, name):
@@ -2346,7 +2324,7 @@ class Subversion(VersionControl):
         from .SvnInfoDialog import SvnInfoDialog
         dlg = SvnInfoDialog(self)
         dlg.start(projectPath, name)
-        dlg.exec_()
+        dlg.exec()
         
     def svnRelocate(self, projectPath):
         """
@@ -2357,7 +2335,7 @@ class Subversion(VersionControl):
         from .SvnRelocateDialog import SvnRelocateDialog
         currUrl = self.svnGetReposName(projectPath)
         dlg = SvnRelocateDialog(currUrl)
-        if dlg.exec_() == QDialog.Accepted:
+        if dlg.exec() == QDialog.Accepted:
             newUrl, inside = dlg.getData()
             if inside:
                 msg = "switch {0} {1}".format(newUrl, projectPath)
@@ -2367,17 +2345,17 @@ class Subversion(VersionControl):
             client = self.getClient()
             dlg = SvnDialog(self.tr('Relocating'), msg, client)
             QApplication.processEvents()
-            locker = QMutexLocker(self.vcsExecutionMutex)
             try:
-                if inside:
-                    client.switch(projectPath, newUrl)
-                else:
-                    client.relocate(currUrl, newUrl, projectPath, recurse=True)
+                with E5MutexLocker(self.vcsExecutionMutex):
+                    if inside:
+                        client.switch(projectPath, newUrl)
+                    else:
+                        client.relocate(currUrl, newUrl, projectPath,
+                                        recurse=True)
             except pysvn.ClientError as e:
                 dlg.showError(e.args[0])
-            locker.unlock()
             dlg.finish()
-            dlg.exec_()
+            dlg.exec()
         
     def svnRepoBrowser(self, projectPath=None):
         """
@@ -2423,15 +2401,14 @@ class Subversion(VersionControl):
             "changelist --remove {0}".format(" ".join(names)),
             client)
         QApplication.processEvents()
-        locker = QMutexLocker(self.vcsExecutionMutex)
         try:
-            for name in names:
-                client.remove_from_changelists(name)
+            with E5MutexLocker(self.vcsExecutionMutex):
+                for name in names:
+                    client.remove_from_changelists(name)
         except pysvn.ClientError as e:
             dlg.showError(e.args[0])
-        locker.unlock()
         dlg.finish()
-        dlg.exec_()
+        dlg.exec()
         
     def svnAddToChangelist(self, names):
         """
@@ -2460,16 +2437,15 @@ class Subversion(VersionControl):
             "changelist {0}".format(" ".join(names)),
             client)
         QApplication.processEvents()
-        locker = QMutexLocker(self.vcsExecutionMutex)
         try:
-            for name in names:
-                client.add_to_changelist(name, clname,
-                                         depth=pysvn.depth.infinity)
+            with E5MutexLocker(self.vcsExecutionMutex):
+                for name in names:
+                    client.add_to_changelist(
+                        name, clname, depth=pysvn.depth.infinity)
         except pysvn.ClientError as e:
             dlg.showError(e.args[0])
-        locker.unlock()
         dlg.finish()
-        dlg.exec_()
+        dlg.exec()
     
     def svnShowChangelists(self, path):
         """
@@ -2493,17 +2469,16 @@ class Subversion(VersionControl):
         client = self.getClient()
         if hasattr(client, 'get_changelist'):
             ppath = e5App().getObject("Project").getProjectPath()
-            locker = QMutexLocker(self.vcsExecutionMutex)
             try:
-                entries = client.get_changelist(ppath,
-                                                depth=pysvn.depth.infinity)
+                with E5MutexLocker(self.vcsExecutionMutex):
+                    entries = client.get_changelist(
+                        ppath, depth=pysvn.depth.infinity)
                 for entry in entries:
                     changelist = entry[1]
                     if changelist not in changelists:
                         changelists.append(changelist)
             except pysvn.ClientError:
                 pass
-            locker.unlock()
         
         return changelists
         
@@ -2519,14 +2494,13 @@ class Subversion(VersionControl):
             "upgrade {0}".format(path),
             client)
         QApplication.processEvents()
-        locker = QMutexLocker(self.vcsExecutionMutex)
         try:
-            client.upgrade(path)
+            with E5MutexLocker(self.vcsExecutionMutex):
+                client.upgrade(path)
         except pysvn.ClientError as e:
             dlg.showError(e.args[0])
-        locker.unlock()
         dlg.finish()
-        dlg.exec_()
+        dlg.exec()
 
     ###########################################################################
     ## Private Subversion specific methods are below.
