@@ -395,7 +395,7 @@ class SvnDiffDialog(QWidget, Ui_SvnDiffDialog):
         try:
             with open(fname, "w", encoding="utf-8", newline="") as f:
                 f.write(eol.join(self.contents.toPlainText().splitlines()))
-        except IOError as why:
+        except OSError as why:
             E5MessageBox.critical(
                 self, self.tr('Save Diff'),
                 self.tr(
