@@ -7,7 +7,6 @@
 Module implementing a tabbed viewmanager class.
 """
 
-
 import os
 
 from PyQt5.QtCore import (
@@ -107,9 +106,9 @@ class TabBar(E5WheelTabBar):
                 str(id(self.parentWidget())).encode("utf-8"))
             drag.setMimeData(mimeData)
             if event.modifiers() == Qt.KeyboardModifiers(Qt.ShiftModifier):
-                drag.exec_(Qt.DropActions(Qt.CopyAction))
+                drag.exec(Qt.DropActions(Qt.CopyAction))
             elif event.modifiers() == Qt.KeyboardModifiers(Qt.NoModifier):
-                drag.exec_(Qt.DropActions(Qt.MoveAction))
+                drag.exec(Qt.DropActions(Qt.MoveAction))
         super(TabBar, self).mouseMoveEvent(event)
     
     def dragEnterEvent(self, event):
@@ -456,6 +455,7 @@ class TabWidget(E5TabWidget):
             fn = editor.getFileName()
             if fn:
                 self.vm.editorLineChanged.emit(fn, lineno + 1)
+            self.vm.editorLineChangedEd.emit(editor, lineno + 1)
         
     def removeWidget(self, widget):
         """
@@ -763,6 +763,8 @@ class Tabview(ViewManager):
         editor's text
     @signal editorLineChanged(str,int) emitted to signal a change of an
         editor's current line (line is given one based)
+    @signal editorLineChangedEd(Editor,int) emitted to signal a change of an
+        editor's current line (line is given one based)
     """
     changeCaption = pyqtSignal(str)
     editorChanged = pyqtSignal(str)
@@ -786,6 +788,7 @@ class Tabview(ViewManager):
     editorLanguageChanged = pyqtSignal(Editor)
     editorTextChanged = pyqtSignal(Editor)
     editorLineChanged = pyqtSignal(str, int)
+    editorLineChangedEd = pyqtSignal(Editor, int)
     
     def __init__(self, parent):
         """
