@@ -344,7 +344,7 @@ class PyRegExpWizardWidget(QWidget, Ui_PyRegExpWizardDialog):
             try:
                 with open(fname, "w", encoding="utf-8") as f:
                     f.write(self.regexpTextEdit.toPlainText())
-            except IOError as err:
+            except OSError as err:
                 E5MessageBox.information(
                     self,
                     self.tr("Save regular expression"),
@@ -368,7 +368,7 @@ class PyRegExpWizardWidget(QWidget, Ui_PyRegExpWizardDialog):
                 with open(fname, "r", encoding="utf-8") as f:
                     regexp = f.read()
                 self.regexpTextEdit.setPlainText(regexp)
-            except IOError as err:
+            except OSError as err:
                 E5MessageBox.information(
                     self,
                     self.tr("Save regular expression"),
