@@ -426,7 +426,7 @@ class QRegularExpressionWizardWidget(QWidget,
             try:
                 with open(fname, "w", encoding="utf-8") as f:
                     f.write(self.regexpTextEdit.toPlainText())
-            except IOError as err:
+            except OSError as err:
                 E5MessageBox.information(
                     self,
                     self.tr("Save regular expression"),
@@ -450,7 +450,7 @@ class QRegularExpressionWizardWidget(QWidget,
                 with open(fname, "r", encoding="utf-8") as f:
                     regexp = f.read()
                 self.regexpTextEdit.setPlainText(regexp)
-            except IOError as err:
+            except OSError as err:
                 E5MessageBox.information(
                     self,
                     self.tr("Save regular expression"),
