@@ -149,7 +149,7 @@ class SetupWizardDialog(QDialog, Ui_SetupWizardDialog):
         try:
             with open(filename, "r") as f:
                 lines = f.readlines()
-        except (IOError, OSError) as err:
+        except OSError as err:
             E5MessageBox.warning(
                 self,
                 self.tr("Reading Trove Classifiers"),
