@@ -7,7 +7,6 @@
 Module implementing the Interface configuration page.
 """
 
-
 import glob
 import os
 
@@ -56,6 +55,8 @@ class InterfacePage(ConfigurationPageBase, Ui_InterfacePage):
             Preferences.getUI("BrowsersListContentsByOccurrence"))
         self.uiBrowsersShowHiddenCheckBox.setChecked(
             Preferences.getUI("BrowsersListHiddenFiles"))
+        self.browserShowCodingCheckBox.setChecked(
+            Preferences.getUI("BrowserShowCoding"))
         self.fileFiltersEdit.setText(
             Preferences.getUI("BrowsersFileFilters"))
         
@@ -123,6 +124,9 @@ class InterfacePage(ConfigurationPageBase, Ui_InterfacePage):
         Preferences.setUI(
             "BrowsersListHiddenFiles",
             self.uiBrowsersShowHiddenCheckBox.isChecked())
+        Preferences.setUI(
+            "BrowserShowCoding",
+            self.browserShowCodingCheckBox.isChecked())
         Preferences.setUI(
             "BrowsersFileFilters",
             self.fileFiltersEdit.text())
