@@ -7,7 +7,6 @@
 Module implementing the Security configuration page.
 """
 
-
 from PyQt5.QtCore import pyqtSlot
 from PyQt5.QtWidgets import QDialog
 
@@ -101,7 +100,7 @@ class SecurityPage(ConfigurationPageBase, Ui_SecurityPage):
         if checked:
             from .MasterPasswordEntryDialog import MasterPasswordEntryDialog
             dlg = MasterPasswordEntryDialog("", self)
-            if dlg.exec_() == QDialog.Accepted:
+            if dlg.exec() == QDialog.Accepted:
                 Preferences.setUser(
                     "MasterPassword",
                     dlg.getMasterPassword())
@@ -121,7 +120,7 @@ class SecurityPage(ConfigurationPageBase, Ui_SecurityPage):
         from .MasterPasswordEntryDialog import MasterPasswordEntryDialog
         dlg = MasterPasswordEntryDialog(
             Preferences.getUser("MasterPassword"), self)
-        if dlg.exec_() == QDialog.Accepted:
+        if dlg.exec() == QDialog.Accepted:
             Preferences.setUser(
                 "MasterPassword",
                 dlg.getMasterPassword())
