@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2003 - 2019 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2003 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -8,8 +8,9 @@ Module implementing a dialog for the configuration of eric6's keyboard
 shortcuts.
 """
 
+import re
 
-from PyQt5.QtCore import pyqtSignal, QRegExp, Qt, pyqtSlot
+from PyQt5.QtCore import pyqtSignal, pyqtSlot, Qt
 from PyQt5.QtGui import QKeySequence
 from PyQt5.QtWidgets import QHeaderView, QDialog, QTreeWidgetItem
 
@@ -462,6 +463,7 @@ class ShortcutsDialog(QDialog, Ui_ShortcutsDialog):
         
         @param txt text of the search edit (string)
         """
+        rx = re.compile(re.escape(txt), re.IGNORECASE)
         for topIndex in range(self.shortcutsList.topLevelItemCount()):
             topItem = self.shortcutsList.topLevelItem(topIndex)
             childHiddenCount = 0
@@ -469,8 +471,7 @@ class ShortcutsDialog(QDialog, Ui_ShortcutsDialog):
                 itm = topItem.child(index)
                 if (
                     (self.actionButton.isChecked() and
-                     not QRegExp(txt, Qt.CaseInsensitive).indexIn(
-                        itm.text(0)) > -1) or
+                     rx.search(itm.text(0)) is not None) or
                     (self.shortcutButton.isChecked() and
                      not txt.lower() in itm.text(1).lower() and
                      not txt.lower() in itm.text(2).lower())
