@@ -423,7 +423,7 @@ class CreateDialogCodeDialog(QDialog, Ui_CreateDialogCodeDialog):
                     return
                 with open(tmplName, 'r', encoding="utf-8") as tmplFile:
                     template = tmplFile.read()
-            except IOError as why:
+            except OSError as why:
                 E5MessageBox.critical(
                     self,
                     self.tr("Code Generation"),
@@ -460,7 +460,7 @@ class CreateDialogCodeDialog(QDialog, Ui_CreateDialogCodeDialog):
                     sourceImpl = srcFile.readlines()
                 if not sourceImpl[-1].endswith("\n"):
                     sourceImpl[-1] = "{0}{1}".format(sourceImpl[-1], "\n")
-            except IOError as why:
+            except OSError as why:
                 E5MessageBox.critical(
                     self,
                     self.tr("Code Generation"),
@@ -553,7 +553,7 @@ class CreateDialogCodeDialog(QDialog, Ui_CreateDialogCodeDialog):
         try:
             with open(fn, 'w', encoding="utf-8", newline=newline) as srcFile:
                 srcFile.write("".join(sourceImpl))
-        except IOError as why:
+        except OSError as why:
             E5MessageBox.critical(
                 self,
                 self.tr("Code Generation"),
