@@ -620,7 +620,7 @@ class ProjectFormsBrowser(ProjectBaseBrowser):
         
         try:
             shutil.copy(templateFile, fname)
-        except IOError as e:
+        except OSError as e:
             E5MessageBox.critical(
                 self,
                 self.tr("New Form"),
@@ -766,7 +766,7 @@ class ProjectFormsBrowser(ProjectBaseBrowser):
                         self.tr("The compilation of the form file"
                                 " was successful."))
                 self.project.projectFormCompiled.emit(self.compiledFile)
-            except IOError as msg:
+            except OSError as msg:
                 if not self.noDialog:
                     E5MessageBox.information(
                         self,
