@@ -499,7 +499,7 @@ class ProjectResourcesBrowser(ProjectBaseBrowser):
                     rcfile.write('<qresource>\n')
                     rcfile.write('</qresource>\n')
                     rcfile.write('</RCC>\n')
-            except IOError as e:
+            except OSError as e:
                 E5MessageBox.critical(
                     self,
                     self.tr("New Resource"),
@@ -612,7 +612,7 @@ class ProjectResourcesBrowser(ProjectBaseBrowser):
                         self.tr("Resource Compilation"),
                         self.tr("The compilation of the resource file"
                                 " was successful."))
-            except IOError as msg:
+            except OSError as msg:
                 if not self.noDialog:
                     E5MessageBox.information(
                         self,
@@ -816,7 +816,7 @@ class ProjectResourcesBrowser(ProjectBaseBrowser):
         try:
             with open(filename, "r", encoding="utf-8") as f:
                 buf = f.read()
-        except IOError:
+        except OSError:
             return False
         
         qrcDirName = os.path.dirname(filename)
