@@ -818,7 +818,7 @@ class ProjectTranslationsBrowser(ProjectBaseBrowser):
                             pf.write('\n\n')
                 
                 self.__tmpProjects.append(outFile)
-            except IOError:
+            except OSError:
                 E5MessageBox.critical(
                     self,
                     self.tr("Write temporary project file"),
@@ -959,7 +959,7 @@ class ProjectTranslationsBrowser(ProjectBaseBrowser):
                     self.__tmpProjects.remove(
                         self.__pylupdateProcesses[index][1])
                     os.remove(self.__pylupdateProcesses[index][1])
-                except EnvironmentError:
+                except OSError:
                     pass
                 del self.__pylupdateProcesses[index]
                 break
@@ -1065,7 +1065,7 @@ class ProjectTranslationsBrowser(ProjectBaseBrowser):
                 try:
                     self.__tmpProjects.remove(tempProjectFile)
                     os.remove(tempProjectFile)
-                except EnvironmentError:
+                except OSError:
                     pass
         
     def __generateAll(self):
