@@ -456,7 +456,7 @@ class ExporterHTML(ExporterBase):
                 with E5OverrideCursor():
                     with open(filename, "w", encoding="utf-8") as f:
                         f.write(html)
-            except IOError as err:
+            except OSError as err:
                 E5MessageBox.critical(
                     self.editor,
                     self.tr("Export source"),
