@@ -7,7 +7,6 @@
 Module implementing a compatability interface class to QsciScintilla.
 """
 
-
 from PyQt5.QtCore import pyqtSignal, Qt, QPoint
 from PyQt5.QtGui import QPalette, QColor, QFontMetrics
 from PyQt5.QtWidgets import QApplication, QListWidget
@@ -47,12 +46,7 @@ class QsciScintillaCompat(QsciScintilla):
     
     UserSeparator = '\x04'
     
-    if QSCINTILLA_VERSION() < 0x020A00:
-        IndicatorStyleMax = QsciScintilla.INDIC_TEXTFORE
-    elif QSCINTILLA_VERSION() < 0x020B00:
-        IndicatorStyleMax = QsciScintilla.INDIC_POINTCHARACTER
-    else:
-        IndicatorStyleMax = QsciScintilla.INDIC_GRADIENTCENTRE
+    IndicatorStyleMax = QsciScintilla.INDIC_GRADIENTCENTRE
     
     def __init__(self, parent=None):
         """
@@ -1575,8 +1569,8 @@ class QsciScintillaCompat(QsciScintilla):
                 height += (
                     userListWidget.horizontalScrollBar().sizeHint().height()
                 )
-                # List box doesn't honor limited size to show scroll bars, e.g.
-                # Python 2 on Win 10. So just force it.
+                # List box doesn't honor limited size to show scroll bars.
+                # So just force it.
                 userListWidget.setHorizontalScrollBarPolicy(
                     Qt.ScrollBarAlwaysOn)
             
@@ -1645,17 +1639,6 @@ class QsciScintillaCompat(QsciScintilla):
     ## methods to implement workarounds for broken things
     ###########################################################################
     
-    if QSCINTILLA_VERSION() == 0x020B00:
-        def insert(self, txt):
-            """
-            Public method to insert text at the cursor position.
-            
-            @param txt text to be inserted
-            @type str
-            """
-            line, col = self.getCursorPosition()
-            self.insertAt(txt, line, col)
-    
     def positionFromLineIndex(self, line, index):
         """
         Public method to convert line and index to an absolute position.
@@ -1709,54 +1692,6 @@ class QsciScintillaCompat(QsciScintilla):
             for line in folds:
                 self.foldLine(line)
     
-    #########################################################################
-    ## Method below implements a compatibility variant for the findFirst()
-    ## extended with version 2.11.
-    #########################################################################
-
-    def findFirst(self, expression, regexp, caseSensitive, word, wrap,
-                  forward=True, line=-1, index=-1, show=True, posix=False,
-                  cxx11=False):
-        """
-        Public method to search in the current editor text.
-        
-        @param expression search expression
-        @type str
-        @param regexp flag indicating a regular expression
-        @type bool
-        @param caseSensitive flag indicating a case sensitive search
-        @type bool
-        @param word flag indicating a word only search
-        @type bool
-        @param wrap flag indicating to warp around
-        @type bool
-        @param forward flag indicating the search direction
-        @type bool
-        @param line line to start the search on
-        @type int
-        @param index index to start the search on
-        @type int
-        @param show flag indicating to set the selection to the found
-            expression
-        @type bool
-        @param posix flag indicating the POSIX regular expression search mode
-        @type bool
-        @param cxx11 flag indicating the CXX11 regular expression search mode
-        @type bool
-        @return flag indicating a successful search
-        @rtype bool
-        """
-        if QSCINTILLA_VERSION() >= 0x020B00:
-            return super(QsciScintillaCompat, self).findFirst(
-                expression, regexp, caseSensitive, word, wrap,
-                forward=forward, line=line, index=index, show=show,
-                posix=posix, cxx11=cxx11)
-        else:
-            return super(QsciScintillaCompat, self).findFirst(
-                expression, regexp, caseSensitive, word, wrap,
-                forward=forward, line=line, index=index, show=show,
-                posix=posix)
-    
     #########################################################################
     ## Methods below are missing from QScintilla.
     #########################################################################
