@@ -241,7 +241,8 @@ class ShellWindow(E5MainWindow):
             'Restart the shell'))
         self.restartAct.setWhatsThis(self.tr(
             """<b>Restart</b>"""
-            """<p>Restart the shell for the currently selected language.</p>"""
+            """<p>Restart the shell for the currently selected"""
+            """ environment.</p>"""
         ))
         self.restartAct.triggered.connect(self.__shell.doRestart)
         self.fileActions.append(self.restartAct)
@@ -256,7 +257,7 @@ class ShellWindow(E5MainWindow):
         self.clearRestartAct.setWhatsThis(self.tr(
             """<b>Restart and Clear</b>"""
             """<p>Clear the shell window and restart the shell for the"""
-            """ currently selected language.</p>"""
+            """ currently selected environment.</p>"""
         ))
         self.clearRestartAct.triggered.connect(self.__shell.doClearRestart)
         self.fileActions.append(self.clearRestartAct)
@@ -280,11 +281,9 @@ class ShellWindow(E5MainWindow):
             self.copyActGrp, 'vm_edit_cut')
         self.cutAct.setStatusTip(QCoreApplication.translate(
             'ViewManager', 'Cut the selection'))
-        self.cutAct.setWhatsThis(QCoreApplication.translate(
-            'ViewManager',
+        self.cutAct.setWhatsThis(self.tr(
             """<b>Cut</b>"""
-            """<p>Cut the selected text of the current editor to the"""
-            """ clipboard.</p>"""
+            """<p>Cut the selected text to the clipboard.</p>"""
         ))
         self.cutAct.triggered.connect(self.__shell.cut)
         self.editActions.append(self.cutAct)
@@ -300,11 +299,9 @@ class ShellWindow(E5MainWindow):
             self.copyActGrp, 'vm_edit_copy')
         self.copyAct.setStatusTip(QCoreApplication.translate(
             'ViewManager', 'Copy the selection'))
-        self.copyAct.setWhatsThis(QCoreApplication.translate(
-            'ViewManager',
+        self.copyAct.setWhatsThis(self.tr(
             """<b>Copy</b>"""
-            """<p>Copy the selected text of the current editor to the"""
-            """ clipboard.</p>"""
+            """<p>Copy the selected text to the clipboard.</p>"""
         ))
         self.copyAct.triggered.connect(self.__shell.copy)
         self.editActions.append(self.copyAct)
@@ -320,11 +317,9 @@ class ShellWindow(E5MainWindow):
             self.copyActGrp, 'vm_edit_paste')
         self.pasteAct.setStatusTip(QCoreApplication.translate(
             'ViewManager', 'Paste the last cut/copied text'))
-        self.pasteAct.setWhatsThis(QCoreApplication.translate(
-            'ViewManager',
+        self.pasteAct.setWhatsThis(self.tr(
             """<b>Paste</b>"""
-            """<p>Paste the last cut/copied text from the clipboard to"""
-            """ the current editor.</p>"""
+            """<p>Paste the last cut/copied text from the clipboard.</p>"""
         ))
         self.pasteAct.triggered.connect(self.__shell.paste)
         self.editActions.append(self.pasteAct)
@@ -339,10 +334,9 @@ class ShellWindow(E5MainWindow):
             self.copyActGrp, 'vm_edit_clear')
         self.clearAct.setStatusTip(QCoreApplication.translate(
             'ViewManager', 'Clear all text'))
-        self.clearAct.setWhatsThis(QCoreApplication.translate(
-            'ViewManager',
+        self.clearAct.setWhatsThis(self.tr(
             """<b>Clear</b>"""
-            """<p>Delete all text of the current editor.</p>"""
+            """<p>Delete all text.</p>"""
         ))
         self.clearAct.triggered.connect(self.__shell.clear)
         self.editActions.append(self.clearAct)
@@ -750,8 +744,8 @@ class ShellWindow(E5MainWindow):
         self.searchAct.setWhatsThis(QCoreApplication.translate(
             'ViewManager',
             """<b>Search</b>"""
-            """<p>Search for some text in the current editor. A"""
-            """ dialog is shown to enter the searchtext and options"""
+            """<p>Search for some text in the shell window. A"""
+            """ dialog is shown to enter the search text and options"""
             """ for the search.</p>"""
         ))
         self.searchAct.triggered.connect(self.__showFind)
@@ -771,8 +765,8 @@ class ShellWindow(E5MainWindow):
         self.searchNextAct.setWhatsThis(QCoreApplication.translate(
             'ViewManager',
             """<b>Search next</b>"""
-            """<p>Search the next occurrence of some text in the current"""
-            """ editor. The previously entered searchtext and options are"""
+            """<p>Search the next occurrence of some text in the shell"""
+            """ window. The previously entered search text and options are"""
             """ reused.</p>"""
         ))
         self.searchNextAct.triggered.connect(
@@ -792,8 +786,8 @@ class ShellWindow(E5MainWindow):
         self.searchPrevAct.setWhatsThis(QCoreApplication.translate(
             'ViewManager',
             """<b>Search previous</b>"""
-            """<p>Search the previous occurrence of some text in the current"""
-            """ editor. The previously entered searchtext and options are"""
+            """<p>Search the previous occurrence of some text in the shell"""
+            """ window. The previously entered search text and options are"""
             """ reused.</p>"""
         ))
         self.searchPrevAct.triggered.connect(
