@@ -736,7 +736,7 @@ class TaskViewer(QTreeWidget):
                 try:
                     text, encoding = Utilities.readEncodedFile(fn)
                     lines = text.splitlines()
-                except (UnicodeError, IOError):
+                except (UnicodeError, OSError):
                     count += 1
                     progress.setValue(count)
                     continue
@@ -852,7 +852,7 @@ class ProjectTaskExtractionThread(QThread):
             try:
                 text, encoding = Utilities.readEncodedFile(fn)
                 lines = text.splitlines()
-            except (UnicodeError, IOError):
+            except (UnicodeError, OSError):
                 continue
             
             # now search tasks and record them
