@@ -7,12 +7,11 @@
 Module implementing the UI Previewer main window.
 """
 
-
 from PyQt5.QtCore import QDir, QFileInfo, QEvent, QSize, Qt
-from PyQt5.QtGui import QCursor, QKeySequence, QImageWriter, QPainter
+from PyQt5.QtGui import QKeySequence, QImageWriter, QPainter
 from PyQt5.QtWidgets import (
     QSizePolicy, QSpacerItem, QWidget, QHBoxLayout, QWhatsThis, QDialog,
-    QScrollArea, qApp, QApplication, QStyleFactory, QFrame, QMainWindow,
+    QScrollArea, QApplication, QStyleFactory, QFrame, QMainWindow,
     QComboBox, QVBoxLayout, QAction, QLabel
 )
 from PyQt5.QtPrintSupport import QPrinter, QPrintDialog
@@ -21,6 +20,8 @@ from PyQt5 import uic
 
 from E5Gui import E5MessageBox, E5FileDialog
 from E5Gui.E5MainWindow import E5MainWindow
+from E5Gui.E5Application import e5App
+from E5Gui.E5OverrideCursor import E5OverrideCursor
 
 import Preferences
 import UI.PixmapCache
@@ -184,7 +185,7 @@ class UIPreviewer(E5MainWindow):
             """<b>Quit</b>"""
             """<p>Quit the application.</p>"""
         ))
-        self.exitAct.triggered.connect(qApp.closeAllWindows)
+        self.exitAct.triggered.connect(e5App().closeAllWindows)
         
         self.copyAct = QAction(
             UI.PixmapCache.getIcon("editCopy"), self.tr('&Copy'), self)
@@ -345,7 +346,7 @@ class UIPreviewer(E5MainWindow):
         # load the file
         try:
             self.mainWidget = uic.loadUi(fn)
-        except Exception:
+        except Exception:       # secok
             pass
         
         if self.mainWidget:
@@ -375,26 +376,25 @@ class UIPreviewer(E5MainWindow):
         
         @param sstyle name of the selected style (string)
         """
-        QApplication.setOverrideCursor(QCursor(Qt.WaitCursor))
-        qstyle = QStyleFactory.create(sstyle)
-        self.mainWidget.setStyle(qstyle)
-        
-        lst = self.mainWidget.findChildren(QWidget)
-        for obj in lst:
-            try:
-                obj.setStyle(qstyle)
-            except AttributeError:
-                pass
-        del lst
-        
-        self.mainWidget.hide()
-        self.mainWidget.show()
-        
-        self.lastQStyle = qstyle
-        self.lastStyle = sstyle
-        Preferences.Prefs.settings.setValue(
-            'UIPreviewer/style', self.styleCombo.currentIndex())
-        QApplication.restoreOverrideCursor()
+        with E5OverrideCursor():
+            qstyle = QStyleFactory.create(sstyle)
+            self.mainWidget.setStyle(qstyle)
+            
+            lst = self.mainWidget.findChildren(QWidget)
+            for obj in lst:
+                try:
+                    obj.setStyle(qstyle)
+                except AttributeError:
+                    pass
+            del lst
+            
+            self.mainWidget.hide()
+            self.mainWidget.show()
+            
+            self.lastQStyle = qstyle
+            self.lastStyle = sstyle
+            Preferences.Prefs.settings.setValue(
+                'UIPreviewer/style', self.styleCombo.currentIndex())
     
     def __updateActions(self):
         """
@@ -530,7 +530,7 @@ class UIPreviewer(E5MainWindow):
             QPrinter.ColorMode(int(settings.value("UIPreviewer/colormode"))))
         
         printDialog = QPrintDialog(printer, self)
-        if printDialog.exec_() == QDialog.Accepted:
+        if printDialog.exec() == QDialog.Accepted:
             self.statusBar().showMessage(self.tr("Printing the image..."))
             self.__print(printer)
             
@@ -574,7 +574,7 @@ class UIPreviewer(E5MainWindow):
         
         preview = QPrintPreviewDialog(printer, self)
         preview.paintRequested.connect(self.__print)
-        preview.exec_()
+        preview.exec()
         
     def __print(self, printer):
         """
