@@ -462,7 +462,7 @@ class FindFileDialog(QDialog, Ui_FindFileDialog):
             try:
                 text, encoding, hashStr = Utilities.readEncodedFileWithHash(fn)
                 lines = text.splitlines(True)
-            except (UnicodeError, IOError):
+            except (UnicodeError, OSError):
                 progress += 1
                 self.findProgress.setValue(progress)
                 continue
@@ -625,7 +625,7 @@ class FindFileDialog(QDialog, Ui_FindFileDialog):
                         Utilities.readEncodedFileWithHash(fn)
                     )
                     lines = text.splitlines(True)
-                except (UnicodeError, IOError) as err:
+                except (UnicodeError, OSError) as err:
                     E5MessageBox.critical(
                         self,
                         self.tr("Replace in Files"),
@@ -666,7 +666,7 @@ class FindFileDialog(QDialog, Ui_FindFileDialog):
                 txt = "".join(lines)
                 try:
                     Utilities.writeEncodedFile(fn, txt, encoding)
-                except (IOError, Utilities.CodingError, UnicodeError) as err:
+                except (OSError, Utilities.CodingError, UnicodeError) as err:
                     E5MessageBox.critical(
                         self,
                         self.tr("Replace in Files"),
