@@ -499,7 +499,7 @@ class PreviewProcessingThread(QThread):
                 try:
                     with open(incFile, "r") as f:
                         incTxt = f.read()
-                except (IOError, OSError):
+                except OSError:
                     # remove SSI include
                     incTxt = ""
             else:
