@@ -9,7 +9,6 @@ Module implementing a background service for the various checkers and other
 python interpreter dependent functions.
 """
 
-
 import json
 import os
 import struct
@@ -67,17 +66,15 @@ class BackgroundService(QTcpServer):
         ## Note: Need the port if started external in debugger:
         print('BackgroundService listening on: {0:d}'.format(port))
         # __IGNORE_WARNING__
-        for pyName in ['Python2', 'Python3']:
-            venvName = Preferences.getDebugger(
-                pyName + "VirtualEnv")
-            interpreter = e5App().getObject(
-                "VirtualEnvManager").getVirtualenvInterpreter(venvName)
-            if not interpreter and int(pyName[-1]) == sys.version_info[0]:
-                interpreter = sys.executable.replace("w.exe", ".exe")
-            if interpreter:
-                process = self.__startExternalClient(interpreter, port)
-                if process:
-                    self.processes[pyName] = process, interpreter
+        venvName = Preferences.getDebugger("Python3VirtualEnv")
+        interpreter = e5App().getObject(
+            "VirtualEnvManager").getVirtualenvInterpreter(venvName)
+        if not interpreter:
+            interpreter = sys.executable.replace("w.exe", ".exe")
+        if interpreter:
+            process = self.__startExternalClient(interpreter, port)
+            if process:
+                self.processes['Python3'] = process, interpreter
 
     def __startExternalClient(self, interpreter, port):
         """
@@ -150,6 +147,7 @@ class BackgroundService(QTcpServer):
         Private method to receive the response from the clients.
         
         @param lang language of the incomming connection (str)
+        @exception RuntimeError raised if hashes don't match
         """
         connection = self.connections[lang]
         while connection.bytesAvailable():
@@ -167,8 +165,8 @@ class BackgroundService(QTcpServer):
                     connection.waitForReadyRead(50)
                 packedData += connection.read(maxSize)
 
-            assert adler32(packedData) & 0xffffffff == datahash, \
-                'Hashes not equal'
+            if adler32(packedData) & 0xffffffff != datahash:
+                raise RuntimeError('Hashes not equal')
             packedData = packedData.decode('utf-8')
             # "check" if is's a tuple of 3 values
             fx, fn, data = json.loads(packedData)
@@ -246,19 +244,17 @@ class BackgroundService(QTcpServer):
         """
         Public slot to restart the built in languages.
         """
-        for pyName in ['Python2', 'Python3']:
-            venvName = Preferences.getDebugger(
-                pyName + "VirtualEnv")
-            interpreter = e5App().getObject(
-                "VirtualEnvManager").getVirtualenvInterpreter(venvName)
-            if not interpreter and int(pyName[-1]) == sys.version_info[0]:
-                interpreter = sys.executable.replace("w.exe", ".exe")
-            
-            # Tweak the processes list to reflect the changed interpreter
-            proc, inter = self.processes.pop(pyName, [None, None])
-            self.processes[pyName] = proc, interpreter
-            
-            self.restartService(pyName)
+        venvName = Preferences.getDebugger("Python3VirtualEnv")
+        interpreter = e5App().getObject(
+            "VirtualEnvManager").getVirtualenvInterpreter(venvName)
+        if not interpreter:
+            interpreter = sys.executable.replace("w.exe", ".exe")
+        
+        # Tweak the processes list to reflect the changed interpreter
+        proc, inter = self.processes.pop('Python3', [None, None])
+        self.processes['Python3'] = proc, interpreter
+        
+        self.restartService('Python3')
 
     def restartService(self, language, forceKill=False):
         """
@@ -451,4 +447,6 @@ class BackgroundService(QTcpServer):
         
         for process, _interpreter in self.processes.values():
             process.close()
+            if not process.waitForFinished(10000):
+                process.kill()
             process = None
