@@ -377,7 +377,7 @@ def readmodule_ex(module, path=None, inpackage=False, isPyFile=False):
 
     try:
         src = Utilities.readEncodedFile(file)[0]
-    except (UnicodeError, IOError):
+    except (UnicodeError, OSError):
         # can't do anything with this module
         _modules[module] = {}
         return {}
