@@ -276,7 +276,7 @@ def readmodule_ex(module, path=None):
 
     try:
         src = Utilities.readEncodedFile(file)[0]
-    except (UnicodeError, IOError):
+    except (UnicodeError, OSError):
         # can't do anything with this module
         _modules[module] = {}
         return {}
