@@ -1597,7 +1597,7 @@ def readModule(module, path=None, inpackage=False, basename="",
     try:
         src = Utilities.readEncodedFile(file)[0]
         mod.scan(src)
-    except (UnicodeError, IOError):
+    except (UnicodeError, OSError):
         pass
     if caching:
         _modules[modname] = mod
