@@ -78,21 +78,40 @@ coding_regexps = [
 
 supportedCodecs = [
     'utf-8',
-    'iso8859-1', 'iso8859-15', 'iso8859-2', 'iso8859-3',
-    'iso8859-4', 'iso8859-5', 'iso8859-6', 'iso8859-7',
-    'iso8859-8', 'iso8859-9', 'iso8859-10', 'iso8859-11',
-    'iso8859-13', 'iso8859-14', 'iso8859-16', 'latin-1',
-    'koi8-r', 'koi8-u',
-    'utf-16', 'utf-32',
-    'cp037', 'cp424', 'cp437', 'cp500', 'cp737', 'cp775',
-    'cp850', 'cp852', 'cp855', 'cp856', 'cp857', 'cp860',
-    'cp861', 'cp862', 'cp863', 'cp864', 'cp865', 'cp866',
-    'cp869', 'cp874', 'cp875', 'cp932', 'cp949', 'cp950',
-    'cp1006', 'cp1026', 'cp1140', 'cp1250', 'cp1251',
-    'cp1252', 'cp1253', 'cp1254', 'cp1255', 'cp1256',
-    'cp1257', 'cp1258',
-    'gb2312', 'gb18030',
-    'ascii'
+    
+    'iso-8859-1', 'iso-8859-2', 'iso-8859-3',
+    'iso-8859-4', 'iso-8859-5', 'iso-8859-6', 'iso-8859-7',
+    'iso-8859-8', 'iso-8859-9', 'iso-8859-10', 'iso-8859-11',
+    'iso-8859-13', 'iso-8859-14', 'iso-8859-15', 'iso-8859-16',
+    'latin-1',
+    
+    'koi8-r', 'koi8-t', 'koi8-u',
+    
+    'utf-7',
+    'utf-16', 'utf-16-be', 'utf-16-le',
+    'utf-32', 'utf-32-be', 'utf-32-le',
+    
+    'cp037', 'cp273', 'cp424', 'cp437', 'cp500', 'cp720',
+    'cp737', 'cp775', 'cp850', 'cp852', 'cp855', 'cp856',
+    'cp857', 'cp858', 'cp860', 'cp861', 'cp862', 'cp863',
+    'cp864', 'cp865', 'cp866', 'cp869', 'cp874', 'cp875',
+    'cp932', 'cp949', 'cp950', 'cp1006', 'cp1026', 'cp1125',
+    'cp1140',
+    
+    'windows-1250', 'windows-1251', 'windows-1252', 'windows-1253',
+    'windows-1254', 'windows-1255', 'windows-1256', 'windows-1257',
+    'windows-1258',
+    
+    'gb2312', 'hz', 'gb18030', 'gbk',
+    
+    'iso-2022-jp', 'iso-2022-jp-1', 'iso-2022-jp-2', 'iso-2022-jp-2004',
+    'iso-2022-jp-3', 'iso-2022-jp-ext', 'iso-2022-kr',
+    
+    'mac-cyrillic', 'mac-greek', 'mac-iceland', 'mac-latin2',
+    'mac-roman', 'mac-turkish',
+    
+    'ascii',
+    'big5-tw', 'big5-hkscs',
 ]
 
 
@@ -661,7 +680,7 @@ def extractFlagsFromFile(filename):
     """
     try:
         source, encoding = readEncodedFile(filename)
-    except (UnicodeError, IOError):
+    except (UnicodeError, OSError):
         return {}
     
     return extractFlags(source)
@@ -724,7 +743,7 @@ def toNativeSeparators(path):
     @return path with converted separator characters (string)
     """
     return QDir.toNativeSeparators(path)
-    
+
 
 def fromNativeSeparators(path):
     """
@@ -734,7 +753,7 @@ def fromNativeSeparators(path):
     @return path with converted separator characters (string)
     """
     return QDir.fromNativeSeparators(path)
-    
+
 
 def normcasepath(path):
     """
@@ -745,17 +764,7 @@ def normcasepath(path):
     @return case normalized path (string)
     """
     return os.path.normcase(os.path.normpath(path))
-    
 
-def normabspath(path):
-    """
-    Function returning a normalized, absolute path.
-    
-    @param path file path (string)
-    @return absolute, normalized path (string)
-    """
-    return os.path.abspath(path)
-    
 
 def normcaseabspath(path):
     """
@@ -766,18 +775,18 @@ def normcaseabspath(path):
     @return absolute, normalized path (string)
     """
     return os.path.normcase(os.path.abspath(path))
-    
+
 
 def normjoinpath(a, *p):
     """
     Function returning a normalized path of the joined parts passed into it.
     
     @param a first path to be joined (string)
-    @param p variable number of path parts to be joind (string)
+    @param p variable number of path parts to be joined (string)
     @return normalized path (string)
     """
     return os.path.normpath(os.path.join(a, *p))
-    
+
 
 def normabsjoinpath(a, *p):
     """
@@ -789,30 +798,6 @@ def normabsjoinpath(a, *p):
     @return absolute, normalized path (string)
     """
     return os.path.abspath(os.path.join(a, *p))
-    
-
-def relpath(path, start=os.path.curdir):
-    """
-    Return a relative version of a path.
-    
-    @param path path to make relative (string)
-    @param start path to make relative from (string)
-    @return relative path (string)
-    @exception ValueError raised to indicate an invalid path
-    """
-    if not path:
-        raise ValueError("no path specified")
-
-    start_list = os.path.abspath(start).split(os.path.sep)
-    path_list = os.path.abspath(path).split(os.path.sep)
-
-    # Work out how much of the filepath is shared by start and path.
-    i = len(os.path.commonprefix([start_list, path_list]))
-
-    rel_list = [os.path.pardir] * (len(start_list) - i) + path_list[i:]
-    if not rel_list:
-        return os.path.curdir
-    return os.path.join(*rel_list)
 
 
 def isinpath(file):
@@ -855,8 +840,8 @@ def startswithPath(path, start):
     if start:
         if path == start:
             return True
-        elif normcasepath(toNativeSeparators(path)).startswith(
-                normcasepath(toNativeSeparators(start + "/"))):
+        elif normcasepath(path).startswith(
+                normcasepath(start + "/")):
             return True
         else:
             return False
@@ -864,27 +849,6 @@ def startswithPath(path, start):
         return False
 
 
-def relativePath(path, start):
-    """
-    Function to convert a file path to a path relative to a start path.
-    
-    @param path file or directory name to convert (string)
-    @param start start path (string)
-    @return relative path or unchanged path, if path does not start with
-        the start path (string)
-    """
-    if startswithPath(path, start):
-        if path == start:
-            return ""
-        else:
-            if start.endswith(("/", "\\")):
-                return path[len(start):]
-            else:
-                return path[len(start) + 1:]
-    else:
-        return path
-
-
 def relativeUniversalPath(path, start):
     """
     Function to convert a file path to a path relative to a start path
@@ -895,7 +859,7 @@ def relativeUniversalPath(path, start):
     @return relative path or unchanged path, if path does not start with
         the start path with universal separators (string)
     """
-    return fromNativeSeparators(relativePath(path, start))
+    return fromNativeSeparators(os.path.relpath(path, start))
 
 
 def absolutePath(path, start):
@@ -908,7 +872,7 @@ def absolutePath(path, start):
     @return absolute path (string)
     """
     if not os.path.isabs(path):
-        path = os.path.join(start, path)
+        path = os.path.normpath(os.path.join(start, path))
     return path
 
 
@@ -922,7 +886,7 @@ def absoluteUniversalPath(path, start):
     @return absolute path with native separators (string)
     """
     if not os.path.isabs(path):
-        path = toNativeSeparators(os.path.join(start, path))
+        path = toNativeSeparators(os.path.normpath(os.path.join(start, path)))
     return path
 
 
@@ -1250,7 +1214,7 @@ def getDirs(path, excludeDirs):
     """
     try:
         names = os.listdir(path)
-    except EnvironmentError:
+    except OSError:
         return []
 
     dirs = []
@@ -2039,7 +2003,7 @@ def generateDistroInfo(linesep='\n'):
                 try:
                     with open(rfile, "r") as f:
                         lines = f.read().splitlines()
-                except IOError:
+                except OSError:
                     continue
                 
                 info.append('  {0}'.format(rfile))
