@@ -246,7 +246,7 @@ class VcsProjectHelper(QObject):
                 if not os.path.isdir(projectdir):
                     try:
                         os.makedirs(projectdir)
-                    except EnvironmentError:
+                    except OSError:
                         E5MessageBox.critical(
                             self.parent(),
                             QCoreApplication.translate(
