@@ -8,7 +8,6 @@ Module implementing a dialog to enter the interpreter for a virtual
 environment.
 """
 
-
 import os
 
 from PyQt5.QtCore import pyqtSlot
@@ -76,4 +75,4 @@ class VirtualenvInterpreterSelectionDialog(
         @return path of the selected Python interpreter
         @rtype str
         """
-        return self.pythonExecPicker.text(),
+        return self.pythonExecPicker.text()
