@@ -473,7 +473,7 @@ class AdBlockSubscription(QObject):
         try:
             with open(fileName, "r", encoding="utf-8") as f:
                 data = f.read()
-        except (IOError, OSError):
+        except (OSError, OSError):
             return False
         
         match = re.search(self.__checksumRe, data)
