@@ -130,7 +130,7 @@ class GreaseMonkeyManager(QObject):
             if deleteScript:
                 try:
                     os.remove(fileName)
-                except (IOError, OSError):
+                except OSError:
                     # ignore
                     pass
     
@@ -177,7 +177,7 @@ class GreaseMonkeyManager(QObject):
                 try:
                     with open(fileName, "r", encoding="utf-8") as f:
                         source = f.read().strip()
-                except (IOError, OSError):
+                except OSError:
                     source = ""
                 if source:
                     script += source + "\n"
