@@ -8,7 +8,6 @@
 Module implementing the web browser using QWebEngineView.
 """
 
-
 import os
 
 from PyQt5.QtCore import (
@@ -18,12 +17,13 @@ from PyQt5.QtCore import (
 from PyQt5.QtGui import (
     QDesktopServices, QClipboard, QIcon, QContextMenuEvent, QPixmap, QCursor
 )
-from PyQt5.QtWidgets import qApp, QStyle, QMenu, QApplication, QDialog
+from PyQt5.QtWidgets import QStyle, QMenu, QApplication, QDialog
 from PyQt5.QtWebEngineWidgets import (
     QWebEngineView, QWebEnginePage, QWebEngineDownloadItem
 )
 
 from E5Gui import E5MessageBox, E5FileDialog
+from E5Gui.E5Application import e5App
 
 from WebBrowser.WebBrowserWindow import WebBrowserWindow
 from .WebBrowserPage import WebBrowserPage
@@ -32,7 +32,7 @@ from .Tools.WebIconLoader import WebIconLoader
 from .Tools import Scripts
 
 from . import WebInspector
-from .Tools.WebBrowserTools import readAllFileContents, pixmapToDataUrl
+from .Tools.WebBrowserTools import getHtmlPage, pixmapToDataUrl
 
 import Preferences
 import UI.PixmapCache
@@ -169,9 +169,12 @@ class WebBrowserView(QWebEngineView):
             # pre Qt 5.12
             pass
         try:
+            from PyQt5.QtWebEngineCore import QWebEngineFindTextResult
+            # __IGNORE_WARNING__
+            
             self.__page.findTextFinished.connect(
                 self.__findTextFinished)
-        except AttributeError:
+        except (AttributeError, ImportError):
             # pre Qt 5.14
             pass
     
@@ -1147,7 +1150,7 @@ class WebBrowserView(QWebEngineView):
         from .Bookmarks.AddBookmarkDialog import AddBookmarkDialog
         dlg = AddBookmarkDialog()
         dlg.setUrl(bytes(url.toEncoded()).decode())
-        dlg.exec_()
+        dlg.exec()
     
     def __sendLink(self, act):
         """
@@ -1343,7 +1346,7 @@ class WebBrowserView(QWebEngineView):
         dlg.setUrl(bytes(self.url().toEncoded()).decode())
         dlg.setTitle(self.title())
         dlg.setDescription(description)
-        dlg.exec_()
+        dlg.exec()
     
     def dragEnterEvent(self, evt):
         """
@@ -1681,6 +1684,14 @@ class WebBrowserView(QWebEngineView):
             self.__siteIconLoader.deleteLater()
         self.__siteIconLoader = WebIconLoader(url, self)
         self.__siteIconLoader.iconLoaded.connect(self.__iconLoaded)
+        try:
+            self.__siteIconLoader.sslConfiguration.connect(
+                self.page().setSslConfiguration)
+            self.__siteIconLoader.clearSslConfiguration.connect(
+                self.page().clearSslConfiguration)
+        except AttributeError:
+            # no SSL available
+            pass
     
     def __iconLoaded(self, icon):
         """
@@ -1768,12 +1779,12 @@ class WebBrowserView(QWebEngineView):
         self.page().deleteLater()
         self.__createNewPage()
         
-        html = readAllFileContents(":/html/tabCrashPage.html")
+        html = getHtmlPage("tabCrashPage.html")
         html = html.replace("@IMAGE@", pixmapToDataUrl(
-            qApp.style().standardIcon(QStyle.SP_MessageBoxWarning).pixmap(
+            e5App().style().standardIcon(QStyle.SP_MessageBoxWarning).pixmap(
                 48, 48)).toString())
         html = html.replace("@FAVICON@", pixmapToDataUrl(
-            qApp.style() .standardIcon(QStyle.SP_MessageBoxWarning).pixmap(
+            e5App().style() .standardIcon(QStyle.SP_MessageBoxWarning).pixmap(
                 16, 16)).toString())
         html = html.replace(
             "@TITLE@", self.tr("Render Process terminated abnormally"))
@@ -2325,7 +2336,7 @@ class WebBrowserView(QWebEngineView):
                     E5SslCertificateSelectionDialog
                 )
                 dlg = E5SslCertificateSelectionDialog(certificates, self)
-                if dlg.exec_() == QDialog.Accepted:
+                if dlg.exec() == QDialog.Accepted:
                     certificate = dlg.getSelectedCertificate()
                 
                 if certificate is None:
