@@ -174,7 +174,7 @@ def cleanUp():
         dirname = os.path.join(pyModDir, installPackage)
         if os.path.exists(dirname):
             shutil.rmtree(dirname, True)
-    except (IOError, OSError) as msg:
+    except OSError as msg:
         sys.stderr.write(
             'Error: {0}\nTry install with admin rights.\n'.format(msg))
         exit(7)
@@ -220,7 +220,7 @@ def installEricDebugClients():
         # copy the license file
         shutilCopy(os.path.join(sourceDir, "docs", "LICENSE.GPL3"), targetDir)
         
-    except (IOError, OSError) as msg:
+    except OSError as msg:
         sys.stderr.write(
             'Error: {0}\nTry install with admin rights.\n'.format(msg))
         return(7)
@@ -297,7 +297,7 @@ def main(argv):
                 shutil.rmtree(distDir, True)
             else:
                 cleanUp()
-    except (IOError, OSError) as msg:
+    except OSError as msg:
         sys.stderr.write('Error: {0}\nTry install as root.\n'.format(msg))
         exit(7)
 
